/* at91m55800.h
   Standard definitions for ATMEL ARM7TDMI controller AT91M55800
*/

#ifndef _AT91M55800_H
#define _AT91M55800_H


/*-------------------------------------*/
/* Peripheral and Interrupt Identifier */
/*-------------------------------------*/

#define FIQ_ID		 0		/* Fast Interrupt */

#define SW_ID		 1		/* Soft Interrupt (generated by the AIC) */

#define US0_ID		 2		/* USART Channel 0 */
#define US1_ID		 3		/* USART Channel 1 */
#define US2_ID		 4		/* USART Channel 2 */

#define SPI_ID		 5		/* SPI Channel */

#define TC0_ID		 6		/* Timer Channel 0 */
#define TC1_ID		 7		/* Timer Channel 1 */
#define TC2_ID		 8		/* Timer Channel 2 */
#define TC3_ID		 9		/* Timer Channel 3 */
#define TC4_ID		10		/* Timer Channel 4 */
#define TC5_ID		11		/* Timer Channel 5 */

#define WD_ID		12		/* Watchdog interrupt */

#define PIOA_ID		13		/* Parallel I/O Controller A interrupt */
#define PIOB_ID		14		/* Parallel I/O Controller B interrupt */

#define AD0_ID		15		/* Analog to Digital Converter Channel 0 interrupt */
#define AD1_ID		16		/* Analog to Digital Converter Channel 1 interrupt */

#define DAC0_ID		17		/* Digital to Analog Converter Channel 0 interrupt */
#define DAC1_ID		18		/* Digital to Analog Converter Channel 1 interrupt */

#define RTC_ID		19		/* Real Time Clock interrupt */

#define APMC_ID		20		/* Advanced Power Management Controller interrupt */

#define SLCKIRQ_ID	23		/* Slow Clock Interrupt */
#define IRQ5_ID		24		/* External interrupt 5 */
#define IRQ4_ID		25		/* External interrupt 4 */
#define IRQ3_ID		26		/* External interrupt 3 */
#define IRQ2_ID		27		/* External interrupt 2 */
#define IRQ1_ID		28		/* External interrupt 1 */
#define IRQ0_ID		29		/* External interrupt 0 */

#define COMMRX_ID	30		/* RX Debug Communication Channel interrupt */
#define COMMTX_ID	31		/* TX Debug Communication Channel interrupt */

#define ISR_MIN		 0
#define ISR_MAX		31
#define ISR_COUNT	31

#define MAXIRQNUM	(ISR_MAX)
#define MAXFIQNUM	(MAXIRQNUM)
#define MAXSWINUM	15

#define NR_IRQS		(MAXIRQNUM + 1)


/*----------------------------------*/
/* External Bus Interface Registers */
/*----------------------------------*/
#define EBI_BASE	0xFFE00000
#define EBI_CSR0	((volatile unsigned *)(EBI_BASE + 0x00))	/* Chip Select Register 0 */
#define EBI_CSR1	((volatile unsigned *)(EBI_BASE + 0x04))	/* Chip Select Register 1 */
#define EBI_CSR2	((volatile unsigned *)(EBI_BASE + 0x08))	/* Chip Select Register 2 */
#define EBI_CSR3	((volatile unsigned *)(EBI_BASE + 0x0C))	/* Chip Select Register 3 */
#define EBI_CSR4	((volatile unsigned *)(EBI_BASE + 0x10))	/* Chip Select Register 4 */
#define EBI_CSR5	((volatile unsigned *)(EBI_BASE + 0x14))	/* Chip Select Register 5 */
#define EBI_CSR6	((volatile unsigned *)(EBI_BASE + 0x18))	/* Chip Select Register 6 */
#define EBI_CSR7	((volatile unsigned *)(EBI_BASE + 0x1C))	/* Chip Select Register 7 */
#define EBI_RCR		((volatile unsigned *)(EBI_BASE + 0x20))	/* Remap Control Register */
#define EBI_MCR		((volatile unsigned *)(EBI_BASE + 0x24))	/* Memory Control Register */

/*------------------------------------------------*/
/* Advanced Power Management Controller Registers */
/*------------------------------------------------*/
#define APMC_BASE	0xFFFF4000
#define APMC_SCER	((volatile unsigned *)(APMC_BASE + 0x00))	/* System Clock Enable  Register */
#define APMC_SCDR	((volatile unsigned *)(APMC_BASE + 0x04))	/* System Clock Disable Register */
#define APMC_SCSR	((volatile unsigned *)(APMC_BASE + 0x08))	/* System Clock Status  Register */
#define APMC_PCER	((volatile unsigned *)(APMC_BASE + 0x10))	/* Peripheral Clock Enable  Register */
#define APMC_PCDR	((volatile unsigned *)(APMC_BASE + 0x14))	/* Peripheral Clock Disable Register */
#define APMC_PCSR	((volatile unsigned *)(APMC_BASE + 0x18))	/* Peripheral Clock Status  Register */
#define APMC_CGMR	((volatile unsigned *)(APMC_BASE + 0x20))	/* Clock Generator Mode Register */
#define APMC_PCR	((volatile unsigned *)(APMC_BASE + 0x28))	/* Power Control Register */
#define APMC_PMR	((volatile unsigned *)(APMC_BASE + 0x2C))	/* Power Mode Register */
#define APMC_SR		((volatile unsigned *)(APMC_BASE + 0x30))	/* Status Register */
#define APMC_IER	((volatile unsigned *)(APMC_BASE + 0x34))	/* Interrupt Enable Register */
#define APMC_IDR	((volatile unsigned *)(APMC_BASE + 0x38))	/* Interrupt Disable Register */
#define APMC_IMR	((volatile unsigned *)(APMC_BASE + 0x3C))	/* Interrupt Mask Register */

/*-----------------------------------------------------------*/
/* Advanced Power Managment Control Register Bits Definition */
/*-----------------------------------------------------------*/
#define APMC_ARM7DIS		0x1		/* disable ARM7 core */

/*------------------------------------------------------------------------*/
/* Advanced Power Managment Clock Generator Mode Register Bits Definition */
/*------------------------------------------------------------------------*/
#define APMC_MOSC_BYP		0x1		/* Main Oscillator Bypass */
#define APMC_MOSC_EN		0x2		/* Main Oscillator Enable */
#define APMC_MCKO_DIS		0x4		/* Disable Master clock output (tri-state) */

#define APMC_PRES_NONE		0x0		/* No prescaler */
#define APMC_PRES_DIV2		0x10	/* Selected Clock Divided by 2 */
#define APMC_PRES_DIV4		0x20	/* Selected Clock Divided by 4 */
#define APMC_PRES_DIV8		0x30	/* Selected Clock Divided by 8 */
#define APMC_PRES_DIV16		0x40	/* Selected Clock Divided by 16 */
#define APMC_PRES_DIV32		0x50	/* Selected Clock Divided by 32 */
#define APMC_PRES_DIV64		0x60	/* Selected Clock Divided by 64 */

#define APMC_CSS_LF			0x0		/* Low-Frequency Clock provided by RTC */
#define APMC_CSS_MOSC		0x4000	/* Main Oscillator Output or External clock */
#define APMC_CSS_PLL		0x8000	/* Phase Lock Loop Output */

#define B_MUL				 8
#define B_OSCOUNT			16
#define B_PLLCOUNT			24

/*------------------------------------------------*/
/* APM Power Controller Register Bits Definition  */
/*------------------------------------------------*/
#define APMC_SHDALC				0x1		/* Shut-down or alarm Command */
#define APMC_WKACKC				0x2		/* Wake-up or Alarm Acknowledge Command */

/*-----------------------------------------------*/
/* APM Power Mode Register Bits Definition       */
/*-----------------------------------------------*/
#define APMC_SHDALS_OUT_TRIS	0x0		/* SHDALS pin is Tri-State */
#define APMC_SHDALS_OUT_LEVEL_0	0x1		/* SHDALS pin is LEVEL 0 */
#define APMC_SHDALS_OUT_LEVEL_1	0x2		/* SHDALS pin LEVEL 1 */

#define APMC_WKACKS_OUT_TRIS	0x0		/* WKACKS pin is Tri-State */
#define APMC_WKACKS_OUT_LEVEL_0	0x4		/* WKACKS pin  is LEVEL 0 */
#define APMC_WKACKS_OUT_LEVEL_1	0x8		/* WKACKS pin  is LEVEL 1 */

#define APMC_WKEN				0x10	/* Alarm Wake-up Enable */
#define APMC_ALSHEN				0x20	/* Alarm Shut-Down Enable */

#define APMC_WKEDG_NONE			0x00	/* None. No edge is detected on Wake-up */
#define APMC_WKEDG_POS_EDG		0x40	/* Positive edge detection */
#define APMC_WKEDG_NEG_EDG		0x80	/* Negative edge detection */

/*------------------------------------------------------*/
/* APM SR, IER, IDR and IMR Registers Bits Definition   */
/*------------------------------------------------------*/
#define APMC_MOSCS				0x1		/* Main Osillator Status */
#define APMC_PLL_LOCK			0x2		/* PLL Lock Status */

/*-----------------------------------------*/
/* Advanced Interrupt Controller Registers */
/*-----------------------------------------*/
#define AIC_BASE	0xFFFFF000
/* Source Mode Register */
#define AIC_SMR0	((volatile unsigned *)(AIC_BASE + 0x000))
#define AIC_SMR1	((volatile unsigned *)(AIC_BASE + 0x004))
#define AIC_SMR2	((volatile unsigned *)(AIC_BASE + 0x008))
#define AIC_SMR3	((volatile unsigned *)(AIC_BASE + 0x00C))
#define AIC_SMR4	((volatile unsigned *)(AIC_BASE + 0x010))
#define AIC_SMR5	((volatile unsigned *)(AIC_BASE + 0x014))
#define AIC_SMR6	((volatile unsigned *)(AIC_BASE + 0x018))
#define AIC_SMR7	((volatile unsigned *)(AIC_BASE + 0x01C))
#define AIC_SMR8	((volatile unsigned *)(AIC_BASE + 0x020))
#define AIC_SMR9	((volatile unsigned *)(AIC_BASE + 0x024))
#define AIC_SMR10	((volatile unsigned *)(AIC_BASE + 0x028))
#define AIC_SMR11	((volatile unsigned *)(AIC_BASE + 0x02C))
#define AIC_SMR12	((volatile unsigned *)(AIC_BASE + 0x030))
#define AIC_SMR13	((volatile unsigned *)(AIC_BASE + 0x034))
#define AIC_SMR14	((volatile unsigned *)(AIC_BASE + 0x038))
#define AIC_SMR15	((volatile unsigned *)(AIC_BASE + 0x03C))
#define AIC_SMR16	((volatile unsigned *)(AIC_BASE + 0x040))
#define AIC_SMR17	((volatile unsigned *)(AIC_BASE + 0x044))
#define AIC_SMR18	((volatile unsigned *)(AIC_BASE + 0x048))
#define AIC_SMR19	((volatile unsigned *)(AIC_BASE + 0x04C))
#define AIC_SMR20	((volatile unsigned *)(AIC_BASE + 0x050))
#define AIC_SMR21	((volatile unsigned *)(AIC_BASE + 0x054))
#define AIC_SMR22	((volatile unsigned *)(AIC_BASE + 0x058))
#define AIC_SMR23	((volatile unsigned *)(AIC_BASE + 0x05C))
#define AIC_SMR24	((volatile unsigned *)(AIC_BASE + 0x060))
#define AIC_SMR25	((volatile unsigned *)(AIC_BASE + 0x064))
#define AIC_SMR26	((volatile unsigned *)(AIC_BASE + 0x068))
#define AIC_SMR27	((volatile unsigned *)(AIC_BASE + 0x06C))
#define AIC_SMR28	((volatile unsigned *)(AIC_BASE + 0x070))
#define AIC_SMR29	((volatile unsigned *)(AIC_BASE + 0x074))
#define AIC_SMR30	((volatile unsigned *)(AIC_BASE + 0x078))
#define AIC_SMR31	((volatile unsigned *)(AIC_BASE + 0x07C))
/* Source Vector Register */
#define AIC_SVR0	((volatile unsigned *)(AIC_BASE + 0x080))
#define AIC_SVR1	((volatile unsigned *)(AIC_BASE + 0x084))
#define AIC_SVR2	((volatile unsigned *)(AIC_BASE + 0x088))
#define AIC_SVR3	((volatile unsigned *)(AIC_BASE + 0x08C))
#define AIC_SVR4	((volatile unsigned *)(AIC_BASE + 0x090))
#define AIC_SVR5	((volatile unsigned *)(AIC_BASE + 0x094))
#define AIC_SVR6	((volatile unsigned *)(AIC_BASE + 0x098))
#define AIC_SVR7	((volatile unsigned *)(AIC_BASE + 0x09C))
#define AIC_SVR8	((volatile unsigned *)(AIC_BASE + 0x0A0))
#define AIC_SVR9	((volatile unsigned *)(AIC_BASE + 0x0A4))
#define AIC_SVR10	((volatile unsigned *)(AIC_BASE + 0x0A8))
#define AIC_SVR11	((volatile unsigned *)(AIC_BASE + 0x0AC))
#define AIC_SVR12	((volatile unsigned *)(AIC_BASE + 0x0B0))
#define AIC_SVR13	((volatile unsigned *)(AIC_BASE + 0x0B4))
#define AIC_SVR14	((volatile unsigned *)(AIC_BASE + 0x0B8))
#define AIC_SVR15	((volatile unsigned *)(AIC_BASE + 0x0BC))
#define AIC_SVR16	((volatile unsigned *)(AIC_BASE + 0x0C0))
#define AIC_SVR17	((volatile unsigned *)(AIC_BASE + 0x0C4))
#define AIC_SVR18	((volatile unsigned *)(AIC_BASE + 0x0C8))
#define AIC_SVR19	((volatile unsigned *)(AIC_BASE + 0x0CC))
#define AIC_SVR20	((volatile unsigned *)(AIC_BASE + 0x0D0))
#define AIC_SVR21	((volatile unsigned *)(AIC_BASE + 0x0D4))
#define AIC_SVR22	((volatile unsigned *)(AIC_BASE + 0x0D8))
#define AIC_SVR23	((volatile unsigned *)(AIC_BASE + 0x0DC))
#define AIC_SVR24	((volatile unsigned *)(AIC_BASE + 0x0E0))
#define AIC_SVR25	((volatile unsigned *)(AIC_BASE + 0x0E4))
#define AIC_SVR26	((volatile unsigned *)(AIC_BASE + 0x0E8))
#define AIC_SVR27	((volatile unsigned *)(AIC_BASE + 0x0EC))
#define AIC_SVR28	((volatile unsigned *)(AIC_BASE + 0x0F0))
#define AIC_SVR29	((volatile unsigned *)(AIC_BASE + 0x0F4))
#define AIC_SVR30	((volatile unsigned *)(AIC_BASE + 0x0F8))
#define AIC_SVR31	((volatile unsigned *)(AIC_BASE + 0x0FC))


#define AIC_IVR		((volatile unsigned *)(AIC_BASE + 0x100))	/* IRQ Vector Register */
#define AIC_FVR		((volatile unsigned *)(AIC_BASE + 0x104))	/* FIQ Vector Register */
#define AIC_ISR		((volatile unsigned *)(AIC_BASE + 0x108))	/* Interrupt Status Register */
#define AIC_IPR		((volatile unsigned *)(AIC_BASE + 0x10C))	/* Interrupt Pending Register */
#define AIC_IMR		((volatile unsigned *)(AIC_BASE + 0x110))	/* Interrupt Mask Register */
#define AIC_CISR	((volatile unsigned *)(AIC_BASE + 0x114))	/* Core Interrupt Status Register */
#define AIC_IECR	((volatile unsigned *)(AIC_BASE + 0x120))	/* Interrupt Enable Command Register */
#define AIC_IDCR	((volatile unsigned *)(AIC_BASE + 0x124))	/* Interrupt Disable Command Register */
#define AIC_ICCR	((volatile unsigned *)(AIC_BASE + 0x128))	/* Interrupt Clear Command Register */
#define AIC_ISCR	((volatile unsigned *)(AIC_BASE + 0x12C))	/* Interrupt Set Command Register */
#define AIC_EOICR	((volatile unsigned *)(AIC_BASE + 0x130))	/* End of Interrupt Command Register */
#define AIC_SPU		((volatile unsigned *)(AIC_BASE + 0x134))	/* Spurious Vector Register */

/*--------------------------------------------*/
/* AIC_SMR[]: Interrupt Source Mode Registers */
/*--------------------------------------------*/

#define AIC_PRIOR						0x07	/* Priority */

#define AIC_SRCTYPE						0x60	/* Source Type Definition */

/* Internal Interrupts */
#define AIC_SRCTYPE_INT_LEVEL_SENSITIVE	0x00	/* Level Sensitive */
#define AIC_SRCTYPE_INT_EDGE_TRIGGERED	0x20	/* Edge Triggered */

/* External Interrupts */
#define AIC_SRCTYPE_EXT_LOW_LEVEL		0x00	/* Low Level */
#define AIC_SRCTYPE_EXT_NEGATIVE_EDGE	0x20	/* Negative Edge */
#define AIC_SRCTYPE_EXT_HIGH_LEVEL		0x40	/* High Level */
#define AIC_SRCTYPE_EXT_POSITIVE_EDGE	0x60	/* Positive Edge */

/*------------------------------------*/
/* AIC_ISR: Interrupt Status Register */
/*------------------------------------*/

#define AIC_IRQID						0x1F	/* Current source interrupt */

/*------------------------------------------*/
/* AIC_CISR: Interrupt Core Status Register */
/*------------------------------------------*/

#define AIC_NFIQ						0x01	/* Core FIQ Status */
#define AIC_NIRQ						0x02	/* Core IRQ Status */



/*---------------------------------------*/
/* User Interface Parallel I/O Interface */
/*---------------------------------------*/
/* Parallel I/O Controller A */
#define PIOA_BASE	0xFFFEC000
#define PIOA_PER	((volatile unsigned *)(PIOA_BASE + 0x00))	/* PIO Enable Register */
#define PIOA_PDR	((volatile unsigned *)(PIOA_BASE + 0x04))	/* PIO Disable Register */
#define PIOA_PSR	((volatile unsigned *)(PIOA_BASE + 0x08))	/* PIO Status Register */
#define PIOA_OER	((volatile unsigned *)(PIOA_BASE + 0x10))	/* Output Enable Register */
#define PIOA_ODR	((volatile unsigned *)(PIOA_BASE + 0x14))	/* Output Disable Register */
#define PIOA_OSR	((volatile unsigned *)(PIOA_BASE + 0x18))	/* Output Status Register */
#define PIOA_IFER	((volatile unsigned *)(PIOA_BASE + 0x20))	/* Input Filter Enable Register */
#define PIOA_IFDR	((volatile unsigned *)(PIOA_BASE + 0x24))	/* Input Filter Disable Register */
#define PIOA_IFSR	((volatile unsigned *)(PIOA_BASE + 0x28))	/* Input Filter Status Register */
#define PIOA_SODR	((volatile unsigned *)(PIOA_BASE + 0x30))	/* Set Output Data Register */
#define PIOA_CODR	((volatile unsigned *)(PIOA_BASE + 0x34))	/* Clear Output Data Register */
#define PIOA_ODSR	((volatile unsigned *)(PIOA_BASE + 0x38))	/* Output Data Status Register */
#define PIOA_PDSR	((volatile unsigned *)(PIOA_BASE + 0x3C))	/* Pin Data Status Register */
#define PIOA_IER	((volatile unsigned *)(PIOA_BASE + 0x40))	/* Interrupt Enable Register */
#define PIOA_IDR	((volatile unsigned *)(PIOA_BASE + 0x44))	/* Interrupt Disable Register */
#define PIOA_IMR	((volatile unsigned *)(PIOA_BASE + 0x48))	/* Interrupt Mask Register */
#define PIOA_ISR	((volatile unsigned *)(PIOA_BASE + 0x4C))	/* Interrupt Status Register */
#define PIOA_MDER	((volatile unsigned *)(PIOA_BASE + 0x50))	/* Multi Driver Enable Register */
#define PIOA_MDDR	((volatile unsigned *)(PIOA_BASE + 0x54))	/* Multi Driver Disable Register */
#define PIOA_MDSR	((volatile unsigned *)(PIOA_BASE + 0x58))	/* Multi Driver Status Register */

/* Parallel I/O Controller B */
#define PIOB_BASE	0xFFFF0000
#define PIOB_PER	((volatile unsigned *)(PIOB_BASE + 0x00))	/* PIO Enable Register */
#define PIOB_PDR	((volatile unsigned *)(PIOB_BASE + 0x04))	/* PIO Disable Register */
#define PIOB_PSR	((volatile unsigned *)(PIOB_BASE + 0x08))	/* PIO Status Register */
#define PIOB_OER	((volatile unsigned *)(PIOB_BASE + 0x10))	/* Output Enable Register */
#define PIOB_ODR	((volatile unsigned *)(PIOB_BASE + 0x14))	/* Output Disable Register */
#define PIOB_OSR	((volatile unsigned *)(PIOB_BASE + 0x18))	/* Output Status Register */
#define PIOB_IFER	((volatile unsigned *)(PIOB_BASE + 0x20))	/* Input Filter Enable Register */
#define PIOB_IFDR	((volatile unsigned *)(PIOB_BASE + 0x24))	/* Input Filter Disable Register */
#define PIOB_IFSR	((volatile unsigned *)(PIOB_BASE + 0x28))	/* Input Filter Status Register */
#define PIOB_SODR	((volatile unsigned *)(PIOB_BASE + 0x30))	/* Set Output Data Register */
#define PIOB_CODR	((volatile unsigned *)(PIOB_BASE + 0x34))	/* Clear Output Data Register */
#define PIOB_ODSR	((volatile unsigned *)(PIOB_BASE + 0x38))	/* Output Data Status Register */
#define PIOB_PDSR	((volatile unsigned *)(PIOB_BASE + 0x3C))	/* Pin Data Status Register */
#define PIOB_IER	((volatile unsigned *)(PIOB_BASE + 0x40))	/* Interrupt Enable Register */
#define PIOB_IDR	((volatile unsigned *)(PIOB_BASE + 0x44))	/* Interrupt Disable Register */
#define PIOB_IMR	((volatile unsigned *)(PIOB_BASE + 0x48))	/* Interrupt Mask Register */
#define PIOB_ISR	((volatile unsigned *)(PIOB_BASE + 0x4C))	/* Interrupt Status Register */
#define PIOB_MDER	((volatile unsigned *)(PIOB_BASE + 0x50))	/* Multi Driver Enable Register */
#define PIOB_MDDR	((volatile unsigned *)(PIOB_BASE + 0x54))	/* Multi Driver Disable Register */
#define PIOB_MDSR	((volatile unsigned *)(PIOB_BASE + 0x58))	/* Multi Driver Status Register */

/*------------------*/
/* Pin Multiplexing */
/*------------------*/
/* PIO Controller A */
#define NB_PIOA		30		/* Number of PIO A Lines */

#define PIOTCLK3	 0		/* Timer 3 Clock signal */
#define PIOTIOA3	 1		/* Timer 3 Signal A */
#define PIOTIOB3	 2		/* Timer 3 Signal B */

#define PIOTCLK4	 3		/* Timer 4 Clock signal */
#define PIOTIOA4	 4		/* Timer 4 Signal A */
#define PIOTIOB4	 5		/* Timer 4 Signal B */

#define PIOTCLK5	 6		/* Timer 5 Clock signal */
#define PIOTIOA5	 7		/* Timer 5 Signal A */
#define PIOTIOB5	 8		/* Timer 5 Signal B */

#define PIOIRQ0		 9		/* External Interrupt 0 */
#define PIOIRQ1		10		/* External Interrupt 1 */
#define PIOIRQ2		11		/* External Interrupt 2 */
#define PIOIRQ3		12		/* External Interrupt 3 */
#define PIOFIQ		13		/* Fast Interrupt */

#define PIOSCK0		14		/* USART 0 signal */
#define PIOTXD0		15		/* USART 0 transmit data */
#define PIORXD0		16		/* USART 0 receive data  */
#define PIOSCK1		17		/* USART 1 clock signal  */
#define PIOTXD1		18		/* USART 1 transmit data */
#define PIORXD1		19		/* USART 1 receive data  */
#define PIOSCK2		20		/* USART 2 signal */
#define PIOTXD2		21		/* USART 2 transmit data */
#define PIORXD2		22		/* USART 2 receive data  */

#define PIOSPCK		23		/* SPI clock signal */
#define PIOMISO		24		/* SPI Master In Slave */
#define PIOMOSI		25		/* SPI Master Out Slave */
#define PIONPCS0	26		/* SPI Peripheral Chip Select 0 */
#define PIONSS		PIONPCS0
#define PIONPCS1	27		/* SPI Peripheral Chip Select 1 */
#define PIONPCS2	28		/* SPI Peripheral Chip Select 2 */
#define PIONPCS3	29		/* SPI Peripheral Chip Select 3 */

/* PIO Controller B */
#define NB_PIOB		28		/* Number of PIO B Lines */

#define PIOIRQ4		 3		/* External Interrupt 4 */
#define PIOIRQ5		 4		/* External Interrupt 5 */
#define PIOSLCKIRQ	 5		/* External Interrupt 6 */

#define PIOAD0TRIG	 6		/* ADC 0 External trigger */
#define PIOAD1TRIG	 7		/* ADC 1 External trigger */

#define PIOBMS		18		/* Boot Mode Select */

#define PIOTCLK0	19		/* Timer 0 Clock signal input */
#define PIOTIOA0	20		/* Timer 0 Signal A   */
#define PIOTIOB0	21		/* Timer 0 Signal B   */

#define PIOTCLK1	22		/* Timer 1 Clock signal */
#define PIOTIOA1	23		/* Timer 1 Signal A */
#define PIOTIOB1	24		/* Timer 1 Signal B */

#define PIOTCLK2	25		/* Timer 2 Clock signal */
#define PIOTIOA2	26		/* Timer 2 Signal A */
#define PIOTIOB2	27		/* Timer 2 Signal B */


/*-----------------------------------*/
/* User Interface Timer/Counter Unit */
/*-----------------------------------*/

/* Timer Control Block 0: Channels 0, 1, 2 */
#define TCB0_BASE	0xFFFD0000
#define TC0_CCR		((volatile unsigned *)(TCB0_BASE + 0x00))	/* Control Register */
#define TC0_CMR		((volatile unsigned *)(TCB0_BASE + 0x04))	/* Mode Register */
#define TC0_CV		((volatile unsigned *)(TCB0_BASE + 0x10))	/* Counter value */
#define TC0_RA		((volatile unsigned *)(TCB0_BASE + 0x14))	/* Register A */
#define TC0_RB		((volatile unsigned *)(TCB0_BASE + 0x18))	/* Register B */
#define TC0_RC		((volatile unsigned *)(TCB0_BASE + 0x1C))	/* Register C */
#define TC0_SR		((volatile unsigned *)(TCB0_BASE + 0x20))	/* Status Register */
#define TC0_IER		((volatile unsigned *)(TCB0_BASE + 0x24))	/* Interrupt Enable Register */
#define TC0_IDR		((volatile unsigned *)(TCB0_BASE + 0x28))	/* Interrupt Disable Register */
#define TC0_IMR		((volatile unsigned *)(TCB0_BASE + 0x2C))	/* Interrupt Mask Register */

#define TC1_CCR		((volatile unsigned *)(TCB0_BASE + 0x40))	/* Control Register */
#define TC1_CMR		((volatile unsigned *)(TCB0_BASE + 0x44))	/* Mode Register */
#define TC1_CV		((volatile unsigned *)(TCB0_BASE + 0x50))	/* Counter value */
#define TC1_RA		((volatile unsigned *)(TCB0_BASE + 0x54))	/* Register A */
#define TC1_RB		((volatile unsigned *)(TCB0_BASE + 0x58))	/* Register B */
#define TC1_RC		((volatile unsigned *)(TCB0_BASE + 0x5C))	/* Register C */
#define TC1_SR		((volatile unsigned *)(TCB0_BASE + 0x60))	/* Status Register */
#define TC1_IER		((volatile unsigned *)(TCB0_BASE + 0x64))	/* Interrupt Enable Register */
#define TC1_IDR		((volatile unsigned *)(TCB0_BASE + 0x68))	/* Interrupt Disable Register */
#define TC1_IMR		((volatile unsigned *)(TCB0_BASE + 0x6C))	/* Interrupt Mask Register */

#define TC2_CCR		((volatile unsigned *)(TCB0_BASE + 0x80))	/* Control Register */
#define TC2_CMR		((volatile unsigned *)(TCB0_BASE + 0x84))	/* Mode Register */
#define TC2_CV		((volatile unsigned *)(TCB0_BASE + 0x90))	/* Counter value */
#define TC2_RA		((volatile unsigned *)(TCB0_BASE + 0x94))	/* Register A */
#define TC2_RB		((volatile unsigned *)(TCB0_BASE + 0x98))	/* Register B */
#define TC2_RC		((volatile unsigned *)(TCB0_BASE + 0x9C))	/* Register C */
#define TC2_SR		((volatile unsigned *)(TCB0_BASE + 0xA0))	/* Status Register */
#define TC2_IER		((volatile unsigned *)(TCB0_BASE + 0xA4))	/* Interrupt Enable Register */
#define TC2_IDR		((volatile unsigned *)(TCB0_BASE + 0xA8))	/* Interrupt Disable Register */
#define TC2_IMR		((volatile unsigned *)(TCB0_BASE + 0xAC))	/* Interrupt Mask Register */

#define TCB0_BCR	((volatile unsigned *)(TCB0_BASE + 0xC0))	/* Block Control Register */
#define TCB0_BMR	((volatile unsigned *)(TCB0_BASE + 0xC4))	/* Block Mode Register  */

/* Timer Control Block 1: Channels 3, 4, 5 */
#define TCB1_BASE	0xFFFD4000
#define TC3_CCR		((volatile unsigned *)(TCB1_BASE + 0x00))	/* Control Register */
#define TC3_CMR		((volatile unsigned *)(TCB1_BASE + 0x04))	/* Mode Register */
#define TC3_CV		((volatile unsigned *)(TCB1_BASE + 0x10))	/* Counter value */
#define TC3_RA		((volatile unsigned *)(TCB1_BASE + 0x14))	/* Register A */
#define TC3_RB		((volatile unsigned *)(TCB1_BASE + 0x18))	/* Register B */
#define TC3_RC		((volatile unsigned *)(TCB1_BASE + 0x1C))	/* Register C */
#define TC3_SR		((volatile unsigned *)(TCB1_BASE + 0x20))	/* Status Register */
#define TC3_IER		((volatile unsigned *)(TCB1_BASE + 0x24))	/* Interrupt Enable Register */
#define TC3_IDR		((volatile unsigned *)(TCB1_BASE + 0x28))	/* Interrupt Disable Register */
#define TC3_IMR		((volatile unsigned *)(TCB1_BASE + 0x2C))	/* Interrupt Mask Register */

#define TC4_CCR		((volatile unsigned *)(TCB1_BASE + 0x40))	/* Control Register */
#define TC4_CMR		((volatile unsigned *)(TCB1_BASE + 0x44))	/* Mode Register */
#define TC4_CV		((volatile unsigned *)(TCB1_BASE + 0x50))	/* Counter value */
#define TC4_RA		((volatile unsigned *)(TCB1_BASE + 0x54))	/* Register A */
#define TC4_RB		((volatile unsigned *)(TCB1_BASE + 0x58))	/* Register B */
#define TC4_RC		((volatile unsigned *)(TCB1_BASE + 0x5C))	/* Register C */
#define TC4_SR		((volatile unsigned *)(TCB1_BASE + 0x60))	/* Status Register */
#define TC4_IER		((volatile unsigned *)(TCB1_BASE + 0x64))	/* Interrupt Enable Register */
#define TC4_IDR		((volatile unsigned *)(TCB1_BASE + 0x68))	/* Interrupt Disable Register */
#define TC4_IMR		((volatile unsigned *)(TCB1_BASE + 0x6C))	/* Interrupt Mask Register */

#define TC5_CCR		((volatile unsigned *)(TCB1_BASE + 0x80))	/* Control Register */
#define TC5_CMR		((volatile unsigned *)(TCB1_BASE + 0x84))	/* Mode Register */
#define TC5_CV		((volatile unsigned *)(TCB1_BASE + 0x90))	/* Counter value */
#define TC5_RA		((volatile unsigned *)(TCB1_BASE + 0x94))	/* Register A */
#define TC5_RB		((volatile unsigned *)(TCB1_BASE + 0x98))	/* Register B */
#define TC5_RC		((volatile unsigned *)(TCB1_BASE + 0x9C))	/* Register C */
#define TC5_SR		((volatile unsigned *)(TCB1_BASE + 0xA0))	/* Status Register */
#define TC5_IER		((volatile unsigned *)(TCB1_BASE + 0xA4))	/* Interrupt Enable Register */
#define TC5_IDR		((volatile unsigned *)(TCB1_BASE + 0xA8))	/* Interrupt Disable Register */
#define TC5_IMR		((volatile unsigned *)(TCB1_BASE + 0xAC))	/* Interrupt Mask Register */

#define TCB1_BCR	((volatile unsigned *)(TCB1_BASE + 0xC0))	/* Block Control Register */
#define TCB1_BMR	((volatile unsigned *)(TCB1_BASE + 0xC4))	/* Block Mode Register  */


/*--------------------------------------------------------*/
/* TC_CCR: Timer Counter Control Register Bits Definition */
/*--------------------------------------------------------*/
#define TC_CLKEN			0x00000001
#define TC_CLKDIS			0x00000002
#define TC_SWTRG			0x00000004

/*---------------------------------------------------------------*/
/* TC_CMR: Timer Counter Channel Mode Register Bits Definition   */
/*---------------------------------------------------------------*/

/*-----------------*/
/* Clock Selection */
/*-----------------*/
#define TC_CLKS				0x00000007
#define TC_CLKS_MCK2		0x0
#define TC_CLKS_MCK8		0x00000001
#define TC_CLKS_MCK32		0x00000002
#define TC_CLKS_MCK128		0x00000003
#define TC_CLKS_MCK1024		0x00000004

#define TC_CLKS_SLCK		0x00000004

#define TC_CLKS_XC0			0x00000005
#define TC_CLKS_XC1			0x00000006
#define TC_CLKS_XC2			0x00000007


/*-----------------*/
/* Clock Inversion */
/*-----------------*/
#define TC_CLKI				0x00000008

/*------------------------*/
/* Burst Signal Selection */
/*------------------------*/
#define TC_BURST			0x00000030
#define TC_BURST_NONE		0x0
#define TC_BUSRT_XC0		0x00000010
#define TC_BURST_XC1		0x00000020
#define TC_BURST_XC2		0x00000030

/*------------------------------------------------------*/
/* Capture Mode : Counter Clock Stopped with RB Loading */
/*------------------------------------------------------*/
#define TC_LDBSTOP			0x00000040

/*-------------------------------------------------------*/
/* Waveform Mode : Counter Clock Stopped with RC Compare */
/*-------------------------------------------------------*/
#define TC_CPCSTOP			0x00000040

/*-------------------------------------------------------*/
/* Capture Mode : Counter Clock Disabled with RB Loading */
/*--------------------------------------------------------*/
#define TC_LDBDIS			0x00000080

/*--------------------------------------------------------*/
/* Waveform Mode : Counter Clock Disabled with RC Compare */
/*--------------------------------------------------------*/
#define TC_CPCDIS			0x00000080

/*------------------------------------------------*/
/* Capture Mode : External Trigger Edge Selection */
/*------------------------------------------------*/
#define TC_ETRGEDG					0x00000300
#define TC_ETRGEDG_EDGE_NONE		0x0
#define TC_ETRGEDG_RISING_EDGE		0x00000100
#define TC_ETRGEDG_FALLING_EDGE		0x00000200
#define TC_ETRGEDG_BOTH_EDGE		0x00000300

/*-----------------------------------------------*/
/* Waveform Mode : External Event Edge Selection */
/*-----------------------------------------------*/
#define TC_EEVTEDG					0x00000300
#define TC_EEVTEDG_EDGE_NONE		0x0
#define TC_EEVTEDG_RISING_EDGE		0x00000100
#define TC_EEVTEDG_FALLING_EDGE		0x00000200
#define TC_EEVTEDG_BOTH_EDGE		0x00000300

/*--------------------------------------------------------*/
/* Capture Mode : TIOA or TIOB External Trigger Selection */
/*--------------------------------------------------------*/
#define TC_ABETRG					0x00000400
#define TC_ABETRG_TIOB				0x0
#define TC_ABETRG_TIOA				0x00000400

/*------------------------------------------*/
/* Waveform Mode : External Event Selection */
/*------------------------------------------*/
#define TC_EEVT						0x00000C00
#define TC_EEVT_TIOB				0x0
#define TC_EEVT_XC0					0x00000400
#define TC_EEVT_XC1					0x00000800
#define TC_EEVT_XC2					0x00000C00

/*--------------------------------------------------*/
/* Waveform Mode : Enable Trigger on External Event */
/*--------------------------------------------------*/
#define TC_ENETRG					0x00001000

/*----------------------------------*/
/* RC Compare Enable Trigger Enable */
/*----------------------------------*/
#define TC_CPCTRG					0x00004000

/*----------------*/
/* Mode Selection */
/*----------------*/
#define TC_WAVE						0x00008000
#define TC_CAPT						0x0

/*-------------------------------------*/
/* Capture Mode : RA Loading Selection */
/*-------------------------------------*/
#define TC_LDRA						0x00030000
#define TC_LDRA_EDGE_NONE			0x0
#define TC_LDRA_RISING_EDGE			0x00010000
#define TC_LDRA_FALLING_EDGE		0x00020000
#define TC_LDRA_BOTH_EDGE			0x00030000

/*-------------------------------------------*/
/* Waveform Mode : RA Compare Effect on TIOA */
/*-------------------------------------------*/
#define TC_ACPA						0x00030000
#define TC_ACPA_OUTPUT_NONE			0x0
#define TC_ACPA_SET_OUTPUT			0x00010000
#define TC_ACPA_CLEAR_OUTPUT		0x00020000
#define TC_ACPA_TOGGLE_OUTPUT		0x00030000

/*-------------------------------------*/
/* Capture Mode : RB Loading Selection */
/*-------------------------------------*/
#define TC_LDRB						0x000C0000
#define TC_LDRB_EDGE_NONE			0x0
#define TC_LDRB_RISING_EDGE			0x00040000
#define TC_LDRB_FALLING_EDGE		0x00080000
#define TC_LDRB_BOTH_EDGE			0x000C0000

/*-------------------------------------------*/
/* Waveform Mode : RC Compare Effect on TIOA */
/*-------------------------------------------*/
#define TC_ACPC						0x000C0000
#define TC_ACPC_OUTPUT_NONE			0x0
#define TC_ACPC_SET_OUTPUT			0x00040000
#define TC_ACPC_CLEAR_OUTPUT		0x00080000
#define TC_ACPC_TOGGLE_OUTPUT		0x000C0000

/*-----------------------------------------------*/
/* Waveform Mode : External Event Effect on TIOA */
/*-----------------------------------------------*/
#define TC_AEEVT					0x00300000
#define TC_AEEVT_OUTPUT_NONE		0x0
#define TC_AEEVT_SET_OUTPUT			0x00100000
#define TC_AEEVT_CLEAR_OUTPUT		0x00200000
#define TC_AEEVT_TOGGLE_OUTPUT		0x00300000

/*-------------------------------------------------*/
/* Waveform Mode : Software Trigger Effect on TIOA */
/*-------------------------------------------------*/
#define TC_ASWTRG					0x00C00000
#define TC_ASWTRG_OUTPUT_NONE		0x0
#define TC_ASWTRG_SET_OUTPUT		0x00400000
#define TC_ASWTRG_CLEAR_OUTPUT		0x00800000
#define TC_ASWTRG_TOGGLE_OUTPUT		0x00C00000

/*-------------------------------------------*/
/* Waveform Mode : RB Compare Effect on TIOB */
/*-------------------------------------------*/
#define TC_BCPB						0x01000000
#define TC_BCPB_OUTPUT_NONE			0x0
#define TC_BCPB_SET_OUTPUT			0x01000000
#define TC_BCPB_CLEAR_OUTPUT		0x02000000
#define TC_BCPB_TOGGLE_OUTPUT		0x03000000

/*-------------------------------------------*/
/* Waveform Mode : RC Compare Effect on TIOB */
/*-------------------------------------------*/
#define TC_BCPC						0x0C000000
#define TC_BCPC_OUTPUT_NONE			0x0
#define TC_BCPC_SET_OUTPUT			0x04000000
#define TC_BCPC_CLEAR_OUTPUT		0x08000000
#define TC_BCPC_TOGGLE_OUTPUT		0x0C000000

/*-----------------------------------------------*/
/* Waveform Mode : External Event Effect on TIOB */
/*-----------------------------------------------*/
#define TC_BEEVT					0x30000000	/* bit 29-28 */
#define TC_BEEVT_OUTPUT_NONE		0x0
#define TC_BEEVT_SET_OUTPUT			0x10000000	/* bit 29-28  01 */
#define TC_BEEVT_CLEAR_OUTPUT		0x20000000	/* bit 29-28  10 */
#define TC_BEEVT_TOGGLE_OUTPUT		0x30000000	/* bit 29-28  11 */

/*- -----------------------------------------------*/
/* Waveform Mode : Software Trigger Effect on TIOB */
/*-------------------------------------------------*/
#define TC_BSWTRG					0xC0000000
#define TC_BSWTRG_OUTPUT_NONE		0x0
#define TC_BSWTRG_SET_OUTPUT		0x40000000
#define TC_BSWTRG_CLEAR_OUTPUT		0x80000000
#define TC_BSWTRG_TOGGLE_OUTPUT		0xC0000000

/*------------------------------------------------------*/
/* TC_SR: Timer Counter Status Register Bits Definition */
/*------------------------------------------------------*/
#define TC_COVFS		0x00000001	/* Counter Overflow Status */
#define TC_LOVRS		0x00000002	/* Load Overrun Status */
#define TC_CPAS			0x00000004	/* RA Compare Status */
#define TC_CPBS			0x00000008	/* RB Compare Status */
#define TC_CPCS			0x00000010	/* RC Compare Status */
#define TC_LDRAS		0x00000020	/* RA Loading Status */
#define TC_LDRBS		0x00000040	/* RB Loading Status */
#define TC_ETRGS		0x00000080	/* External Trigger Status */
#define TC_CLKSTA		0x00010000	/* Clock Status */
#define TC_MTIOA		0x00020000	/* TIOA Mirror */
#define TC_MTIOB		0x00040000	/* TIOB Status */

/*--------------------------------------------------------------*/
/* TC_BCR: Timer Counter Block Control Register Bits Definition */
/*--------------------------------------------------------------*/
#define TC_SYNC			0x00000001	/* Synchronisation Trigger */

/*------------------------------------------------------------*/
/*  TC_BMR: Timer Counter Block Mode Register Bits Definition */
/*------------------------------------------------------------*/
#define TC_TC0XC0S		0x00000003	/* External Clock Signal 0 Selection */
#define TC_TCLK0XC0		0x0
#define TC_NONEXC0		0x00000001
#define TC_TIOA1XC0		0x00000002
#define TC_TIOA2XC0		0x00000003

#define TC_TC1XC1S		0x0000000C	/* External Clock Signal 1 Selection */
#define TC_TCLK1XC1		0x0
#define TC_NONEXC1		0x00000004
#define TC_TIOA0XC1		0x00000008
#define TC_TIOA2XC1		0x0000000C

#define TC_TC2XC2S		0x00000030	/* External Clock Signal 2 Selection */
#define TC_TCLK2XC2		0x0
#define TC_NONEXC2		0x00000010
#define TC_TIOA0XC2		0x00000020
#define TC_TIOA1XC2		0x00000030



/*----------------------*/
/* User Interface USART */
/*----------------------*/

/* USART 0 */
#define USART0_BASE	0xFFFC0000
#define US0_CR		((volatile unsigned *)(USART0_BASE + 0x00))	/* Control Register */
#define US0_MR		((volatile unsigned *)(USART0_BASE + 0x04))	/* Mode Register */
#define US0_IER		((volatile unsigned *)(USART0_BASE + 0x08))	/* Interrupt Enable Register */
#define US0_IDR		((volatile unsigned *)(USART0_BASE + 0x0C))	/* Interrupt Disable Register */
#define US0_IMR		((volatile unsigned *)(USART0_BASE + 0x10))	/* Interrupt Mask Register */
#define US0_CSR		((volatile unsigned *)(USART0_BASE + 0x14))	/* Channel Status Register */
#define US0_RHR		((volatile unsigned *)(USART0_BASE + 0x18))	/* Receive Holding Register */
#define US0_THR		((volatile unsigned *)(USART0_BASE + 0x1C))	/* Transmit Holding Register */
#define US0_BRGR	((volatile unsigned *)(USART0_BASE + 0x20))	/* Baud Rate Generator Register */
#define US0_RTOR	((volatile unsigned *)(USART0_BASE + 0x24))	/* Receiver Timeout Register */
#define US0_TTGR	((volatile unsigned *)(USART0_BASE + 0x28))	/* Transmitter Time-guard Register */
#define US0_RPR		((volatile unsigned *)(USART0_BASE + 0x30))	/* Receiver Pointer Register */
#define US0_RCR		((volatile unsigned *)(USART0_BASE + 0x34))	/* Receiver Counter Register */
#define US0_TPR		((volatile unsigned *)(USART0_BASE + 0x38))	/* Transmitter Pointer Register */
#define US0_TCR		((volatile unsigned *)(USART0_BASE + 0x3C))	/* Transmitter Counter Register */

/* USART 1 */
#define USART1_BASE 	0xFFFC4000
#define US1_CR		((volatile unsigned *)(USART1_BASE + 0x00))	/* Control Register */
#define US1_MR		((volatile unsigned *)(USART1_BASE + 0x04))	/* Mode Register */
#define US1_IER		((volatile unsigned *)(USART1_BASE + 0x08))	/* Interrupt Enable Register */
#define US1_IDR		((volatile unsigned *)(USART1_BASE + 0x0C))	/* Interrupt Disable Register */
#define US1_IMR		((volatile unsigned *)(USART1_BASE + 0x10))	/* Interrupt Mask Register */
#define US1_CSR		((volatile unsigned *)(USART1_BASE + 0x14))	/* Channel Status Register */
#define US1_RHR		((volatile unsigned *)(USART1_BASE + 0x18))	/* Receive Holding Register */
#define US1_THR		((volatile unsigned *)(USART1_BASE + 0x1C))	/* Transmit Holding Register */
#define US1_BRGR	((volatile unsigned *)(USART1_BASE + 0x20))	/* Baud Rate Generator Register */
#define US1_RTOR	((volatile unsigned *)(USART1_BASE + 0x24))	/* Receiver Timeout Register */
#define US1_TTGR	((volatile unsigned *)(USART1_BASE + 0x28))	/* Transmitter Time-guard Register */
#define US1_RPR		((volatile unsigned *)(USART1_BASE + 0x30))	/* Receiver Pointer Register */
#define US1_RCR		((volatile unsigned *)(USART1_BASE + 0x34))	/* Receiver Counter Register */
#define US1_TPR		((volatile unsigned *)(USART1_BASE + 0x38))	/* Transmitter Pointer Register */
#define US1_TCR		((volatile unsigned *)(USART1_BASE + 0x3C))	/* Transmitter Counter Register */

/* USART 2 */
#define USART2_BASE	0xFFFC8000
#define US2_CR		((volatile unsigned *)(USART2_BASE + 0x00))	/* Control Register */
#define US2_MR		((volatile unsigned *)(USART2_BASE + 0x04))	/* Mode Register */
#define US2_IER		((volatile unsigned *)(USART2_BASE + 0x08))	/* Interrupt Enable Register */
#define US2_IDR		((volatile unsigned *)(USART2_BASE + 0x0C))	/* Interrupt Disable Register */
#define US2_IMR		((volatile unsigned *)(USART2_BASE + 0x10))	/* Interrupt Mask Register */
#define US2_CSR		((volatile unsigned *)(USART2_BASE + 0x14))	/* Channel Status Register */
#define US2_RHR		((volatile unsigned *)(USART2_BASE + 0x18))	/* Receive Holding Register */
#define US2_THR		((volatile unsigned *)(USART2_BASE + 0x1C))	/* Transmit Holding Register */
#define US2_BRGR	((volatile unsigned *)(USART2_BASE + 0x20))	/* Baud Rate Generator Register */
#define US2_RTOR	((volatile unsigned *)(USART2_BASE + 0x24))	/* Receiver Timeout Register */
#define US2_TTGR	((volatile unsigned *)(USART2_BASE + 0x28))	/* Transmitter Time-guard Register */
#define US2_RPR		((volatile unsigned *)(USART2_BASE + 0x30))	/* Receiver Pointer Register */
#define US2_RCR		((volatile unsigned *)(USART2_BASE + 0x34))	/* Receiver Counter Register */
#define US2_TPR		((volatile unsigned *)(USART2_BASE + 0x38))	/* Transmitter Pointer Register */
#define US2_TCR		((volatile unsigned *)(USART2_BASE + 0x3C))	/* Transmitter Counter Register */


/*--------------------------*/
/* US_CR : Control Register */
/*--------------------------*/

#define US_RSTRX					0x0004	/* Reset Receiver */
#define US_RSTTX					0x0008	/* Reset Transmitter */
#define US_RXEN						0x0010	/* Receiver Enable */
#define US_RXDIS					0x0020	/* Receiver Disable */
#define US_TXEN						0x0040	/* Transmitter Enable */
#define US_TXDIS					0x0080	/* Transmitter Disable */
#define US_RSTSTA					0x0100	/* Reset Status Bits */
#define US_STTBRK					0x0200	/* Start Break */
#define US_STPBRK					0x0400	/* Stop Break */
#define US_STTTO					0x0800	/* Start Time-out */
#define US_SENDA					0x1000	/* Send Address */

/*-----------------------*/
/* US_MR : Mode Register */
/*-----------------------*/

#define US_CLKS						0x0030	/* Clock Selection */
#define US_CLKS_MCK					0x0000	/* Master Clock */
#define US_CLKS_MCK8				0x0010	/* Master Clock divided by 8 */
#define US_CLKS_SCK					0x0020	/* External Clock */
#define US_CLKS_SLCK				0x0030	/* Slow Clock */

#define US_CHRL						0x00C0	/* Byte Length */
#define US_CHRL_5					0x0000	/* 5 bits */
#define US_CHRL_6					0x0040	/* 6 bits */
#define US_CHRL_7					0x0080	/* 7 bits */
#define US_CHRL_8					0x00C0	/* 8 bits */

#define US_SYNC						0x0100	/* Synchronous Mode Enable */

#define US_PAR						0x0E00	/* Parity Mode */
#define US_PAR_EVEN					0x0000	/* Even Parity */
#define US_PAR_ODD					0x0200	/* Odd Parity */
#define US_PAR_SPACE				0x0400	/* Space Parity to 0 */
#define US_PAR_MARK					0x0600	/* Marked Parity to 1 */
#define US_PAR_NO					0x0800	/* No Parity */
#define US_PAR_MULTIDROP			0x0C00	/* Multi-drop Mode */

#define US_NBSTOP               	0x3000	/* Stop Bit Number */
#define US_NBSTOP_1             	0x0000	/* 1 Stop Bit */
#define US_NBSTOP_1_5           	0x1000	/* 1.5 Stop Bits */
#define US_NBSTOP_2             	0x2000	/* 2 Stop Bits */

#define US_CHMODE					0xC000	/* Channel Mode */
#define US_CHMODE_NORMAL			0x0000	/* Normal Mode */
#define US_CHMODE_AUTOMATIC_ECHO	0x4000	/* Automatic Echo */
#define US_CHMODE_LOCAL_LOOPBACK	0x8000	/* Local Loopback */
#define US_CHMODE_REMOTE_LOOPBACK	0xC000	/* Remote Loopback */

#define US_MODE9					0x20000	/* 9 Bit Mode */

#define US_CLKO						0x40000	/* Baud Rate Output Enable */

/* Mode Register model */

/* Standard Asynchronous Mode : 8 bits , 1 stop , no parity */
#define US_ASYNC_MODE		( US_CHMODE_NORMAL + \
							  US_NBSTOP_1 + \
							  US_PAR_NO + \
							  US_CHRL_8 + \
							  US_CLKS_MCK )

/* Standard External Asynchronous Mode : 8 bits , 1 stop , no parity */
#define US_ASYNC_SCK_MODE	( US_CHMODE_NORMAL + \
							  US_NBSTOP_1 + \
							  US_PAR_NO + \
							  US_CHRL_8 + \
							  US_CLKS_SCK )

/* Standard Synchronous Mode : 8 bits , 1 stop , no parity */
#define US_SYNC_MODE		( US_SYNC + \
							  US_CHMODE_NORMAL + \
							  US_NBSTOP_1 + \
							  US_PAR_NO + \
							  US_CHRL_8 + \
							  US_CLKS_MCK )

/* SCK used Label */
#define SCK_USED			(US_CLKO | US_CLKS_SCK)

/*---------------------------------------------------------------*/
/* US_IER, US_IDR, US_IMR, US_CSR: Status and Interrupt Register */
/*---------------------------------------------------------------*/

#define US_RXRDY			0x001	/* Receiver Ready */
#define US_TXRDY			0x002	/* Transmitter Ready */
#define US_RXBRK			0x004	/* Receiver Break */
#define US_ENDRX			0x008	/* End of Receiver PDC Transfer */
#define US_ENDTX			0x010	/* End of Transmitter PDC Transfer */
#define US_OVRE				0x020	/* Overrun Error */
#define US_FRAME			0x040	/* Framing Error */
#define US_PARE				0x080	/* Parity Error */
#define US_TIMEOUT			0x100	/* Receiver Timeout */
#define US_TXEMPTY			0x200	/* Transmitter Empty */

#define US_MASK_IRQ_TX		(US_TXRDY | US_ENDTX | US_TXEMPTY)
#define US_MASK_IRQ_RX		(US_RXRDY | US_ENDRX | US_TIMEOUT)
#define US_MASK_IRQ_ERROR	(US_PARE | US_FRAME | US_OVRE | US_RXBRK)



/* Baud Rate Generator values = MCLK / (16 * baud_val) */

#define SYS_MCKI		32768000	/* maximal clock frequency [Hz] */

/* baud rate values at 32.768 MHz */
#define BAUD_4800		(SYS_MCKI/(16*4800))	/* 4800 baud rate */
#define BAUD_9600		(SYS_MCKI/(16*9600))	/* 9600 baud rate */
#define BAUD_19200		(SYS_MCKI/(16*19200))	/* 19200 baud rate */
#define BAUD_38400		(SYS_MCKI/(16*38400))	/* 38400 baud rate */
#define BAUD_57600		(SYS_MCKI/(16*57600))	/* 57600 baud rate */
#define BAUD_115200		(SYS_MCKI/(16*115200))	/* 115200 baud rate */

#define USTAT			0x14
#define URXBUF			0x18
#define UTXBUF			0x1C

/* UART primitives */
#define GET_STATUS(p)	(*(volatile unsigned *)((p) + USTAT))
#define RX_DATA(s)		((s) & US_RXRDY)
#define GET_CHAR(p)		(*(volatile unsigned *)((p) + URXBUF))
#define TX_READY(s)		((s) & US_TXRDY)
#define PUT_CHAR(p,c)	(*(unsigned *)((p) + UTXBUF) = (unsigned )(c))



/*----------------------------*/
/* Real Time Clock Registers  */
/*----------------------------*/
#define RTC_BASE	0xFFFB8000

#define RTC_CR		((volatile unsigned *)(RTC_BASE + 0x00))	/* Control Register */
#define RTC_MR		((volatile unsigned *)(RTC_BASE + 0x04))	/* Mode Register */
#define RTC_TIMR	((volatile unsigned *)(RTC_BASE + 0x08))	/* Time Register */
#define RTC_CALR	((volatile unsigned *)(RTC_BASE + 0x0C))	/* Calendar Register */
#define RTC_TAR		((volatile unsigned *)(RTC_BASE + 0x10))	/* Time Alarm Register */
#define RTC_CAR		((volatile unsigned *)(RTC_BASE + 0x14))	/* Calendar Alarm Register */
#define RTC_SR		((volatile unsigned *)(RTC_BASE + 0x18))	/* Status Register */
#define RTC_SCCR	((volatile unsigned *)(RTC_BASE + 0x1C))	/* Status Clear Register */
#define RTC_IER		((volatile unsigned *)(RTC_BASE + 0x20))	/* Interrupt Enable Register */
#define RTC_IDR		((volatile unsigned *)(RTC_BASE + 0x24))	/* Interrupt Disable Register */
#define RTC_IMR		((volatile unsigned *)(RTC_BASE + 0x28))	/* Interrupt Mask Register */
#define RTC_VER		((volatile unsigned *)(RTC_BASE + 0x2C))	/* Valid Entry Register */

/*--------------------------------------------*/
/* RTC_CR: Control Register bits definition  */
/*-------------------------------------------*/
#define RTC_UPDTIM				0x00000001	/* Update Request Time Register */
#define RTC_UPDCAL				0x00000002	/* Update Request Calendar Register */
#define RTC_UPD_MASQ			0x00000003	/* Update Request masque */

#define RTC_TEVSEL_MN_CHG		0x00000000	/* Time Event Selection : Minute change */
#define RTC_TEVSEL_HR_CHG		0x00000100	/* Time Event Selection : Hour change */
#define RTC_TEVSEL_EVDAY_MD		0x00000200	/* Time Event Selection : Every Day at Midnight */
#define RTC_TEVSEL_EVDAY_NOON	0x00000300	/* Time Event Selection : Every Day at Noon */
#define RTC_TEVSEL_MASQ         0x00000300	/* Update TEVSEL masque */

#define RTC_CEVSEL_WEEK_CHG		0x00000000	/* Calendar Event Selection : Week Change (every Monday @ 00:00:00) */
#define RTC_CEVSEL_MONTH_CHG	0x00010000	/* Calendar Event Selection : Month Change (every 01 of each month @ 00:00:00) */
#define RTC_CEVSEL_YEAR_CHG		0x00020000	/* Calendar Event Selection : Year Change (every january 1st at 00:00:00) */
#define RTC_CEVSEL_MASQ			0x00030000	/* Updat eCEVSEL masque */

/*-------------------------------------------*/
/* RTC_MR: Mode Register bits definition     */
/*-------------------------------------------*/
#define RTC_24_HRMOD		0x0			/* 24-Hour Mode is selected */
#define RTC_12_HRMOD		0x1			/* 12-Hour Mode is selected */

/*---------------------------------------------*/
/* RTC_TIMR: Time Register bits definition     */
/*---------------------------------------------*/
#define RTC_AM			(0<<22)			/* AM Indicator */
#define RTC_PM			0x00400000		/* PM Indicator */
#define RTC_MASQ_SEC	0x0000007F
#define RTC_MIN			8
#define RTC_MASQ_MIN	0x00007F00
#define RTC_HOUR		16
#define RTC_MASQ_HOUR	0x003F0000
#define RTC_AMPM		22
#define RTC_MASQ_AMPM   0x00400000

/*--------------------------------------------------*/
/* RTC_CALR:  Calendar Register bits definition     */
/*--------------------------------------------------*/
#define RTC_CENT		0
#define RTC_MASQ_CENT	0x0000003F
#define RTC_YEAR		8
#define RTC_MASQ_YEAR	0x0000FF00
#define RTC_MONTH		16
#define RTC_MASQ_MONTH	0x001F0000
#define RTC_DAY			21
#define RTC_MASQ_DAY	0x00E00000
#define RTC_DATE		24
#define RTC_MASQ_DATE	0x3F000000


/*----------------------------------------------*/
/* RTC_TAR: Time Alarm Register bits definition */
/*----------------------------------------------*/
#define RTC_SEC_ALRM_DIS	(0<<7)	/* Second Alarm Disable */
#define RTC_SEC_ALRM_EN		(1<<7)	/* Second Alarm Enable */

#define RTC_MIN_ALRM_DIS	(0<<15)	/* Minute Alarm Disable */
#define RTC_MIN_ALRM_EN		(1<<15)	/* Minute Alarm Enable */

#define RTC_HOUR_ALRM_DIS	(0<<23)	/* Hour Alarm Disable */
#define RTC_HOUR_ALRM_EN	(1<<23)	/* Hour Alarm Enable */

/*--------------------------------------------------*/
/* RTC_CAR: Calendar Alarm Register bits definition */
/*--------------------------------------------------*/
#define RTC_MONTH_ALRM_DIS	(0<<23)	/* Month Alarm Disable */
#define RTC_MONTH_ALRM_EN	(1<<23)	/* Month Alarm Enable */

#define RTC_DATE_ALRM_DIS	(0<<31)	/* Date Alarm Disable */
#define RTC_DATE_ALRM_EN	(1<<31)	/* Date Alarm Enable */

/*-------------------------------------------------------------------------------*/
/* RTC Status, Interrupt Clear, Enable,Disable and Mask Register bits definition */
/*-------------------------------------------------------------------------------*/
#define RTC_ACKUPD			0x01	/* Acknowledge for Update */
#define RTC_ALARM			0x02	/* Alarm Flag */
#define RTC_SEC				0x04	/* Second Event */
#define RTC_TIMEV			0x08	/* Time Event */
#define RTC_CALEV			0x10	/* Calendar Event */

/*-------------------------------------------------*/
/* RTC_VER:Valid Entry Register bits definition    */
/*-------------------------------------------------*/
#define RTC_NVT				0x01	/* Non-Valid Time */
#define RTC_NVC				0x02	/* Non-Valid Calendar */
#define RTC_NVTAL			0x04	/* Non-Valid Time Alarm */
#define RTC_NVCAL			0x08	/* Non-Valid Calendar Alarm */



/*------------------------------------*/
/* Chip Identification User Interface */
/*------------------------------------*/
/* Special Function Base Address */
#define SF_BASE		0xFFF00000
#define SF_CIDR		((volatile unsigned *)(SF_BASE + 0x00))	/* Chip ID Register */
#define SF_EXID		((volatile unsigned *)(SF_BASE + 0x04))	/* Chip ID Extension Register */
#define SF_RSR		((volatile unsigned *)(SF_BASE + 0x08))	/* Reset Status Register */
#define SF_PMR		((volatile unsigned *)(SF_BASE + 0x18))	/* Protect Mode Register */

/*-------------------------------------------------------*/
/* SF_CIDR: Chip Identification Register Bits Definition */
/*-------------------------------------------------------*/

#define SF_VERSION			0x1F		/* Version Number */
#define SF_NVPSIZ			(0x0F<<8)	/* Non Volatile Program Memory Size */
#define SF_NVDSIZ			(0x0F<<12)	/* Non Volatile Data Memory Size */
#define SF_VDSIZ			(0x0F<<16)	/* Volatile Data Memory Size */
#define SF_ARCH				(0xFF<<20)	/* Architecture Code */
#define SF_NVPTYP			(0x07<<28)	/* Non Volatile Program Memory Type */
#define SF_EXT				(0x1U<<31)	/* Extension Flag */


/* SF_ARCH: */
#define SF_ARCH_AT91x63		(0x63<<20)
#define SF_ARCH_AT91x40		(0x40<<20)
#define SF_ARCH_AT91x55		(0x55<<20)

/* SF_NVPSIZ */
#define SF_NVPSIZ_NONE		(0<<8)
#define SF_NVPSIZ_32K		(3<<8)
#define SF_NVPSIZ_64K		(5<<8)
#define SF_NVPSIZ_128K		(7<<8)
#define SF_NVPSIZ_256K		(9<<8)

/* SF_NVDSIZ */
#define SF_NVDSIZ_NONE		0
/* SF_VDSIZ */
#define SF_VDSIZ_NONE		(0<<16)
#define SF_VDSIZ_1K			(1<<16)
#define SF_VDSIZ_2K			(2<<16)
#define SF_VDSIZ_4K			(4<<16)
#define SF_VDSIZ_8K			(8<<16)

/* SF_NVPTYP */
#define SF_NVPTYP_M			(1<<28)	/* M or F series */
#define SF_NVPTYP_C			(2<<28)	/* C series */
#define SF_NVPTYP_S			(3<<28)	/* S series */
#define SF_NVPTYP_R			(4<<28)	/* R series */
/*------------------------------------------*/
/* SF_RSR: Reset Status Register Definition */
/*------------------------------------------*/

#define SF_EXT_RESET		0x6C	/* External pin Cause Reset */
#define SF_WD_RESET			0x53	/* Internal WatchDog Cause Reset */

/*----------------------------------*/
/* SF_PMR: Protect Control Register */
/*----------------------------------*/

#define SF_AIC				(0x1<<5)



#endif /* _AT91M55800_H */
