/********************************************************************************/
/*	FILE 		: Hello.C						*/
/*										*/
/*	DESCRIPTION 	: Hello Program for PHYTEC-Board phyCORE-AT91M55800A	*/
/*										*/
/*			  Output at COM1 with 19200 Baud		 	*/
/*										*/
/*	AUTHOR		: A.Beuscher						*/
/*			  PHYTEC Metechnik GmbH				*/
/*										*/
/*	VERSOIN		: V1.00							*/
/*										*/
/*	TOOLCHAIN	: HIGHTEC GNU ARM Development Suite 1.0			*/
/*										*/
/*	DATE		: 12.12.2002						*/
/********************************************************************************/
 
/* Includes */
#include <stdio.h>
#include <stddef.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>

#include "../h/at91m55800.h"
#include "../h/rs232.h"

#define BUFSIZE		128
#define BAUDRATE	19200		//38400

#define LED_PIN		0x00000001

#define LED_OFF		*PIOA_SODR = LED_PIN;
#define LED_ON		*PIOA_CODR = LED_PIN;

char *my_str = {"\r\nHello world!"};


static void InitLED(void)
{
	*PIOA_PER = LED_PIN;	/* enable Pin */
	*PIOA_OER = LED_PIN;	/* enable as output */
	LED_OFF;
}

void my_printf(const char *fmt, ...)
{
	char buffer[BUFSIZE], *ptr;
	va_list ap;

	va_start(ap, fmt);
	vsprintf(buffer, fmt, ap);
	va_end(ap);

	for (ptr = buffer; *ptr; ++ptr)
		_out_uart((unsigned char) *ptr);
}

int main(void)
{
	unsigned char c;
	int quit = 0;

	_init_uart(BAUDRATE);
	InitLED();

	my_printf(my_str);
	my_printf("\r\nYour choice please");

	while (!quit)
	{
		c = _in_uart();
		switch (c)
		{
			case '0' :
				LED_OFF;
				my_printf("\r\nLED switched to OFF");
				break;
			case '1' :
				LED_ON;
				my_printf("\r\nLED switched to ON");
				break;
			case '2' :
				my_printf(my_str);
				break;
			case 'E' :
				quit = 1;
				my_printf("\r\nBye bye!");
				break;
			default :
				my_printf("\r\nCommand '%c' not supported\r\n", c);
				break;
		}
	}

	return EXIT_SUCCESS;
}
