/*
 * rs232.c -- Transmit and receice characters via serial line
 *            (polling variant).
 */

#include "../h/at91m55800.h"
#include "../h/rs232.h"

#define UARTBASE	USART0_BASE

/* Initialize asynchroneous interface (UART0) to operate at BAUDRATE,8,n,1.  */

void _init_uart(int baudrate)
{
	unsigned baud;

	switch (baudrate)
	{
		case   9600 : baud = BAUD_9600;   break;
		case  19200 : baud = BAUD_19200;  break;
		case  38400 : baud = BAUD_38400;  break;
		case  57600 : baud = BAUD_57600;  break;
		case 115200 : baud = BAUD_115200; break;
		default     : baud = BAUD_38400;  break;
	}


	*APMC_PCER |= 0x04;		/* Enable USARTs clock */
	*PIOA_PDR  |= 0x00018000;	/* Enable RXD0 and TXD0 */
	*US0_CR     = 0x000000AC;	/* Disable RX and TX / Reset Logic */
	*US0_RCR    = 0x00;
	*US0_TCR    = 0x00;
	*US0_BRGR   = baud;
	*US0_MR     = 0x000008C0;	/* 8 bits, no Parity, 1 Stop bit */
	*US0_CR     = 0x00000050;	/* Enable RX and TX  */
}


/* Send character CHR via the serial line.  */

void _out_uart(unsigned char chr)
{
	/* wait until port is ready for transmitting a new character */
	while (TX_READY(GET_STATUS(UARTBASE)) == 0)
		;

	/* and send it */
	PUT_CHAR(UARTBASE, chr);
}

/* Receive (and wait for) a character from the serial line.  */

unsigned char _in_uart(void)
{
	unsigned char ch;

	/* wait for a new character in RXBUF */
	while (!(RX_DATA(GET_STATUS(UARTBASE))))
		;

	/* read the character, this also resets any error flags */
	ch = GET_CHAR(UARTBASE);

	return ch;
}

/* Check the serial line if a character has been received.
   returns 1 and the character in *chr if there is one
   else 0
 */

int _poll_uart(unsigned char *chr)
{
	int res = 0;

	if (RX_DATA(GET_STATUS(UARTBASE)))
	{
		*chr = (unsigned char) GET_CHAR(UARTBASE);
		res = 1;
	}

	return res;
}
