/*********************************************************************
  Modul:     Irq.H
  Projekt:
  Zweck:     Verwaltung der IRQ - Interruptserviceroutinen

  Autor:     Willi Thei
  Copyright:

  Stand:     31.03.2001
  31.03.2001 Anpassung der Version fr LH77790
*********************************************************************/

#ifndef _IRQ_H
#define _IRQ_H

/* Definition der Interruptquellen --> phyCORE-AT91M55800A*/

#define FIQ 	0
#define SWIRQ	1
#define US0IRQ	2
#define US1IRQ	3
#define US2IRQ	4
#define SPIRQ	5
#define TC0IRQ	6
#define TC1IRQ	7
#define TC2IRQ	8
#define TC3IRQ	9
#define TC4IRQ	10
#define TC5IRQ	11
#define WDIRQ	12
#define PIOAIRQ	13
#define PIOBIRQ 14
#define ADC0IRQ 15
#define ADC1IRQ 16
#define DAC0IRQ 17
#define DAC1IRQ 18
#define RTCIRQ	19
#define APMCIRQ 20
#define SLCKIRQ 23
#define IRQ5	24
#define IRQ4	25
#define IRQ3	26
#define IRQ2	27
#define IRQ1	28
#define IRQ0	29
#define COMMTX	30
#define COMMRX	31

//#define TCB0_BASE 0xFFFD0000
//#define TCB1_BASE 0xFFFD4000

/* Typdefinition einer Interruptserviceroutine (ISR) */
typedef void (*PFV)(void);


/*---------------------------------------------------------------------
    Funktion:  IrqInit
    Aufgabe:   Initialisierung der KS32C50100 - IRQ - Behandlung
    Parameter: void
    Rckgabe:  void
---------------------------------------------------------------------*/
void IrqInit(void);

/*---------------------------------------------------------------------
    Funktion:  IrqEnable
    Aufgabe:   Aktivierung eines bestimmten IRQ-Interruptes
    Parameter: int irqNum - Nummer des IRQ-Interruptes
    Rckgabe:  void
---------------------------------------------------------------------*/
void IrqEnable(int irqNum);

/*---------------------------------------------------------------------
    Funktion:  IrqDisable
    Aufgabe:   Deaktivierung eines bestimmten IRQ-Interruptes
    Parameter: int irqNum - Nummer des IRQ-Interruptes
    Rckgabe:  void
---------------------------------------------------------------------*/
void IrqDisable(int irqNum);

/*---------------------------------------------------------------------
    Funktion:  IrqInstall
    Aufgabe:   Installation eines IRQ-Interruptservicehandlers
    Parameter: int irqNum  - Nummer des IRQ-Interruptes
               PFV isrProc - Zeiger auf Serviceroutine
               int enable  - Flag "Interrupt aktivieren"
    Rckgabe:  PFV         - Zeiger auf alten ISR-Handler
---------------------------------------------------------------------*/
PFV IrqInstall(int irqNum, PFV isrProc, int enable, int priority);

/*---------------------------------------------------------------------
    Funktion:  IrqHandler
    Aufgabe:   Verwaltungsprozedur fr IRQ-Interrupts
    Parameter: void
    Rckgabe:  void
---------------------------------------------------------------------*/
void IrqHandler(void);

#endif // _IRQ_H
