/*********************************************************************
    Modul:     Irq.C
    Projekt:
    Zweck:     Verwaltung der IRQ - Interruptserviceroutinen

    Autor:     Willi Thei
    Copyright:

    Stand:     12.07.2001
    12.07.2001 INTMOD in Init setzen
    03.07.2002 Anpassung auf phyCORE-AT91M55800A A.Beuscher
*********************************************************************/

#include "irq.h"
#include "periph/aic/aic.h"

typedef unsigned char byte;

/*
 * Priority resolution table
 * Index with a bit mask and you get the highest priority in the mask
 * which is set in the mask.  Least significant bit is highest priority.
 */
#define MAXIRQNUM	32
#define IRQ_MAX_NUM     MAXIRQNUM

//static PFV irqVector[IRQ_MAX_NUM];


/*---------------------------------------------------------------------
    Funktion:  IrqInit
    Task: Initializing Irq 
    Parameter: void
    return value:  void
---------------------------------------------------------------------*/
void IrqInit(void)
	{
    	int i;
	StructAIC *IRQptr;
	
	IRQptr = AIC_BASE;
	
  	IRQptr->AIC_IDCR = 0xff9fffff;	// disable all interrupts
	IRQptr->AIC_ICCR = 0xff9fffff;	// clear all interrupts
	
//    *INTPND = 0xff9fffff;     /* clear pending interrupts */
//    *INTMSK = 0xff9fffff;     /* mask off all interrupts  */
//    *INTMOD = 0;            /* interrupts mapped to IRQ */

    /* Clear the interrupt vector table in the AIC-registers */
    for (i = 0; i < IRQ_MAX_NUM; ++i)
    {
        IRQptr->AIC_SVR[i] = 0x00;//(PFV) 0;
    }
}

/*---------------------------------------------------------------------
    Funktion:  IrqEnable
    Task :  activating of a defined interupt
    Parameter: int irqNum - Number of IRQ-Interrupt
    return value:  void
---------------------------------------------------------------------*/
void IrqEnable(int irqNum)
	{
	StructAIC *IRQptr;
	
	IRQptr = AIC_BASE;
	
    	if ((irqNum < IRQ_MAX_NUM) && (irqNum >= 0))
    		{
    		IRQptr->AIC_IECR |= ( 1 << irqNum );
//#if 0
        /* clear any pending interrupt on that channel */
//        *INTPND  = (1 << irqNum);
//#endif
        /* enable it: force global disable OFF */
//        *INTMSK &= ~((1 << INT_GLOBAL) | (1 << irqNum));
    		}
	}

/*---------------------------------------------------------------------
    Funktion:  IrqDisable
    Task:   Deactivating defined interrupts
    Parameter: int irqNum - Number of IRQ-Interrupt
    return value:  void
---------------------------------------------------------------------*/
void IrqDisable(int irqNum)
	{
	StructAIC *IRQptr;
	
	IRQptr = AIC_BASE;
	
    	if ((irqNum < IRQ_MAX_NUM) && (irqNum >= 0))
		IRQptr->AIC_IDCR |= ( 1 << irqNum);
        //	*INTMSK |= (1 << irqNum);
	}

/*---------------------------------------------------------------------
    Funktion:  IrqInstall
    Task:   Installation of IRQ-Interruptservicehandler
    Parameter: int irqNum  - Number des IRQ-Interruptes
               PFV isrProc - pointer of the Serviceroutine
               int enable  - Flag "Interrupt aktiv"
    return value:  PFV         - Pointer of old ISR-Handler
---------------------------------------------------------------------*/
PFV IrqInstall(int irqNum, PFV isrProc, int enable, int priority)
	{
    	PFV oldIsr;
	StructAIC *IRQptr;
	
	IRQptr = AIC_BASE;

    	if (irqNum < 0 || IRQ_MAX_NUM <= irqNum)
    		{
        	return ((PFV) 0);
    		}

    oldIsr = (PFV)IRQptr->AIC_SVR[irqNum];
    (PFV)IRQptr->AIC_SVR[irqNum] = isrProc;
    if (enable)
    {
        IrqEnable(irqNum);
    }

    return (oldIsr);
}

