/******************************************************************
 *****                                                        *****
 *****  Name: easyweb.c                                       *****
 *****  Ver.: 1.0                                             *****
 *****  Date: 07/05/2001                                      *****
 *****  Auth: Andreas Dannenberg                              *****
 *****        HTWK Leipzig                                    *****
 *****        university of applied sciences                  *****
 *****        Germany                                         *****
 *****  Func: implements a dynamic HTTP-server by using       *****
 *****        the easyWEB-API                                 *****
 *****                                                        *****
 ******************************************************************/

/********************************************************************************/
/*	FILE 		: easyweb.C						*/
/*										*/
/*	DESCRIPTION 	: easyweb-Programm fr PHYTEC-Board phyCORE-AT91M55800A	*/
/*										*/			  
/*			  Output of the modul specific website		 	*/
/*										*/
/*	ANPASSUNG	: A.Beuscher						*/
/*			  PHYTEC Metechnik GmbH				*/
/*										*/
/*	VERSOIN		: V1.00							*/
/*										*/
/*	TOOLCHAIN	: HIGHTEC GNU ARM Development Suite 1.0			*/
/*										*/
/*	DATE		: 12.12.2002						*/
/********************************************************************************/
  

#define extern            // Keil: Line added for modular project management
//#include "stdlib.h"
//#include "periph/rtc/rtc.h"
#include "rtc.h"
#include "at91m55800.h"
#include "serial.h"
#include "stdio.h"
#include "string.h"
#include "easyweb.h"
#include "cs8900.h"       // Keil: *.c -> *.h    // ethernet packet driver
#include "tcpip.h"        // Keil: *.c -> *.h    // easyWEB TCP/IP stack
//PHYTEC: #include <reg167.h>	      // Keil: Register definition file for 80C167

#include "webside.h"                             // webside for our HTTP server (HTML)
#undef extern
//extern unsigned int uiFrequency;
#define extern     

int main(void)
{
//InitOsc();              // Keil: No oscillator initialization necessary at this time.
//InitPorts();			  // Keil: No port initialization necessary at this time.

  init_serial(COM1);

  TCPLowLevelInit();

  RTCinit();

/*
  *(unsigned char *)RemoteIP = 24;               // uncomment those lines to get the
  *((unsigned char *)RemoteIP + 1) = 8;          // quote of the day from a real
  *((unsigned char *)RemoteIP + 2) = 69;         // internet server! (gateway must be
  *((unsigned char *)RemoteIP + 3) = 7;          // set to your LAN-router)

  TCPLocalPort = 2025;
  TCPRemotePort = TCP_PORT_QOTD;

  TCPActiveOpen();

  while (SocketStatus & SOCK_ACTIVE)             // read the quote from memory
  {                                              // by using the hardware-debugger
    DoNetworkStuff();
  }
*/

  HTTPStatus = 0;                                // clear HTTP-server's flag register

  TCPLocalPort = TCP_PORT_HTTP;                  // set port we want to listen to
  
  while (1)                                      // repeat forever
  {
    if (!(SocketStatus & SOCK_ACTIVE)) TCPPassiveOpen();   // listen for incoming TCP-connection
    DoNetworkStuff();                                      // handle network and easyWEB-stack
                                                           // events
    HTTPServer();
  }
}

// This function implements a very simple dynamic HTTP-server.
// It waits until connected, then sends a HTTP-header and the
// HTML-code stored in memory. Before sending, it replaces
// some special strings with dynamic values.
// NOTE: For strings crossing page boundaries, replacing will
// not work. In this case, simply add some extra lines
// (e.g. CR and LFs) to the HTML-code.

void HTTPServer(void)
{
  if (SocketStatus & SOCK_CONNECTED)             // check if somebody has connected to our TCP
  {
    if (SocketStatus & SOCK_DATA_AVAILABLE)      // check if remote TCP sent data
      TCPReleaseRxBuffer();                      // and throw it away

    if (SocketStatus & SOCK_TX_BUF_RELEASED)     // check if buffer is free for TX
    {
      if (!(HTTPStatus & HTTP_SEND_PAGE))        // init byte-counter and pointer to webside
      {                                          // if called the 1st time
        HTTPBytesToSend = sizeof(WebSide) - 1;   // get HTML length, ignore trailing zero
        PWebSide = (unsigned char *)WebSide;     // pointer to HTML-code
      }

      if (HTTPBytesToSend > MAX_TCP_TX_DATA_SIZE)     // transmit a segment of MAX_SIZE
      {
        if (!(HTTPStatus & HTTP_SEND_PAGE))           // 1st time, include HTTP-header
        {
          memcpy(TCP_TX_BUF, GetResponse, sizeof(GetResponse) - 1);
          memcpy(TCP_TX_BUF + sizeof(GetResponse) - 1, PWebSide, MAX_TCP_TX_DATA_SIZE - sizeof(GetResponse) + 1);
          HTTPBytesToSend -= MAX_TCP_TX_DATA_SIZE - sizeof(GetResponse) + 1;
          PWebSide += MAX_TCP_TX_DATA_SIZE - sizeof(GetResponse) + 1;
        }
        else
        {
          memcpy(TCP_TX_BUF, PWebSide, MAX_TCP_TX_DATA_SIZE);
          HTTPBytesToSend -= MAX_TCP_TX_DATA_SIZE;
          PWebSide += MAX_TCP_TX_DATA_SIZE;
        }
          
        TCPTxDataCount = MAX_TCP_TX_DATA_SIZE;   // bytes to xfer
        InsertDynamicValues();                   // exchange some strings...
        TCPTransmitTxBuffer();                   // xfer buffer
      }
      else if (HTTPBytesToSend)                  // transmit leftover bytes
      {
        memcpy(TCP_TX_BUF, PWebSide, HTTPBytesToSend);
        TCPTxDataCount = HTTPBytesToSend;        // bytes to xfer
        InsertDynamicValues();                   // exchange some strings...
        TCPTransmitTxBuffer();                   // send last segment
        TCPClose();                              // and close connection
        HTTPBytesToSend = 0;                     // all data sent
      }

      HTTPStatus |= HTTP_SEND_PAGE;              // ok, 1st loop executed
    }
  }
  else
    HTTPStatus &= ~HTTP_SEND_PAGE;               // reset help-flag if not connected
}

// searches the TX-buffer for special strings and replaces them
// with dynamic values (for example the temperature)

void InsertDynamicValues(void)
{
  unsigned char *Key;
  char NewKey[12] = "123456789012";
  unsigned short i;
     
  if (TCPTxDataCount < 4) return;       // there can't be any special string
  
  Key = TCP_TX_BUF;
  
  for (i = 0; i < (TCPTxDataCount - 3); i++)
  {
    if (*Key == 'D')
     if (*(Key + 1) == 'V')
       if (*(Key + 3) == '%')
         switch (*(Key + 2))
         {
           case '1' : 
	                                   // "DV1%"?
             sprintf(NewKey, "%02u  ", bcdtoint((*RTC_TIMR >> 16)& 0x3F));     //
             memcpy(Key, NewKey, 4);                  
             break;
           
           case '2' :                                 // "DV2%"?
           
             sprintf(NewKey, "%02u  ", bcdtoint((*RTC_TIMR >> 8)& 0x7F));    // insert module Uptime		 
             memcpy(Key, NewKey, 4);                  
             break;
           
           case '3' :                                 // "DV2%"?
           
             sprintf(NewKey, "%02u  ", bcdtoint(*RTC_TIMR & 0x7F));    // insert module Uptime		 
             memcpy(Key, NewKey, 4);                  
             break;
           

           case '4' :                                 // "DV2%"?
           
             sprintf(NewKey, "%02u  ", bcdtoint((*RTC_CALR >> 24)& 0x3F));    // insert module Uptime		 
             memcpy(Key, NewKey, 4);                  
             break;
           
           case '5' :                                 // "DV2%"?
           
             sprintf(NewKey, "%02u  ", bcdtoint((*RTC_CALR >> 16)& 0x1F));    // insert module Uptime		 
             memcpy(Key, NewKey, 4);                  
             break;
           
           case '6' :                                 // "DV2%"?
           
             sprintf(NewKey, "%02u  ", bcdtoint((*RTC_CALR >> 8) & 0xFF));    // insert module Uptime		 
             memcpy(Key, NewKey, 4);                  
             break;
           

         }
    Key++;
  }
}

