/* header file for registers of 82C900 */
/* (naming according to User Manual)  */
/* INFINEON TECHNOLOGIES               */
/* Microcontroller Application Support */
/* P. Schneidenbach, May 1, 2000       */

#ifndef R_82C900_h
#define R_82C900_h

/* --- Standalone Shell Registers ---  */

#define GLOBCTR 	0x0010 			
/* Global Device Control Register      */
#define INTCTR  	0x0012			
/* Interrupt Control Register          */
#define CLKCTR  	0x0014 			
/* Clock Control Register              */
#define IOMODE0 	0x0020	 		
/* Input/Output Mode Register 0        */
#define IOMODE2 	0x0022	 		
/* Input/Output Mode Register 2        */
#define IOMODE4 	0x0024	 		
/* Input/Output Mode Register 4        */
#define INREG 	0x0026			
/* Input Value Register (8-bit port)	*/ 
#define OUTREG 	0x0028			
/*Output Value Register (8-bit port)	*/
#define CANPWD 	0x0040			
/* Power-Down Control Register      	*/
#define CANIO 	0x0042			
/* CAN Input/Output Control Register	*/ 
#define CANINIT 	0x0044			
/*CAN Initialization Control Register	*/ 
#define PAGE 	0x7C 
/* Paging Mode Register (accessable in all pages) 	*/
#define CAB 		0x007E 			
/* CAN Address Buffer Register 			*/

/* --- CAN Node A Registers --- */

#define	ACR		0x0200
/* Node A Control Register           */
#define	ASR		0x0204
/* Node A Status Register            */
#define	AIR		0x0208
/* Node A Interrupt Pending Register */
#define	ABTR		0x020C
/* Node A Bit Timing Register        */
#define	AGINP		0x0210
/* Node A Global Interrupt Node Pointer Register */
#define	AFCR		0x0214
/* Node A Frame Counter Register     */
#define	AIMR0		0x0218
/* Node A INTID Mask Register 0      */
#define	AIMR4		0x021C
/* Node A INTID Mask Register 4      */
#define	AECNT		0x0220
/* Node A Error Counter Register     */


/* --- CAN Node B Registers --- */

#define	BCR		0x0240
/* Node B Control Register           */
#define	BSR		0x0244
/* Node B Status Register            */
#define	BIR		0x0248
/* Node B Interrupt Pending Register */
#define	BBTR		0x024C
/* Node B Bit Timing Register        */
#define	BGINP		0x0250
/* Node B Global Interrupt Node Pointer Register */
#define	BFCR		0x0254
/* Node B Frame Counter Register     */
#define	BIMR0		0x0258
/* Node B INTID Mask Register 0      */
#define	BIMR4		0x025C
/* Node B INTID Mask Register 4      */
#define	BECNT		0x0260
/* Node B Error Counter Register     */


/* --- Global Control Registers ---    */
#define	RXIPND	0x0284
/* Receive Interrupt Pending Register  */
#define	TXIPND	0x0288
/* Transmit Interrupt Pending Register */

#define INITCTR 	0x02F0 			
/* Initialization Control Register  	  */

/* --- Message Object Base Addresses --- */

#define MOBASE(n) (0x0300 + n * 0x20)

/* --- Message Object Offset Addresses --- */

#define	MSGDRn0	0x00
/* Msg. Obj. n Data Register 0          */
#define	MSGDRn4	0x04
/* Msg. Obj. n Data Register 4          */
#define	MSGARn	0x08
/* Msg. Obj. n Arbitration Register     */
#define	MSGAMRn	0x0C
/* Msg. Obj. n Acceptance Mask Register */
#define	MSGCTRn	0x10
/* Msg. Obj. n Control Register         */
#define	MSGCFGn	0x14
/* Msg. Obj. n Configuration Register   */
#define	MSGFGCRn	0x18
/* Msg. Obj. n FIFO/Gateway Control Register */

#endif
