// #========================================================================
// #
// #    vectors.s
// #
// #    ARM exception vectors
// #
// #========================================================================
// #
// #========================================================================


#define CPSR_IRQ_DISABLE	0x80	/* IRQ disabled when =1	*/
#define CPSR_FIQ_DISABLE	0x40	/* FIQ disabled when =1	*/
#define CPSR_THUMB_ENABLE	0x20	/* Thumb mode when =1	*/
#define CPSR_MODE32_ENABLE	0x10	/* 32 bit mode when =1	*/

#define CPSR_MODE_BITS		0x1F
#define CPSR_USER_MODE		0x10
#define CPSR_FIQ_MODE		0x11
#define CPSR_IRQ_MODE		0x12
#define CPSR_SUPERVISOR_MODE	0x13
#define CPSR_ABORT_MODE		0x17
#define CPSR_UNDEF_MODE		0x1B
#define CPSR_SYSTEM_MODE	0x1F




	.file	"vectors.S"


//; #==========================================================================
//; #  Hardware exception vectors.
//; #  The vector table will be copied to location 0x0000 at startup time.
//;
	.code	32
	.section ".vectors","ax"
	.global	__exception_handlers

	b	start
__exception_handlers:
__vector_table_start:
	ldr	pc,.reset_vector
	ldr	pc,.undefined_instruction
	ldr	pc,.software_interrupt
	ldr	pc,.abort_prefetch
	ldr	pc,.abort_data
	.word	0
	ldr	pc,.IRQ
	ldr	pc,.FIQ

//; # The layout of these pointers should match the vector table above since
//; # they are copied in pairs.
	.global	vectors
vectors:
.reset_vector:
	.word	reset_vector
.undefined_instruction:
	.word	undefined_instruction
.software_interrupt:
	.word	software_interrupt
.abort_prefetch:
	.word	abort_prefetch
.abort_data:
	.word	abort_data
	.word	0
.IRQ:
	.word	IRQ
.FIQ:
	.word	FIQ

__vector_table_end:

	.text
//; Startup code which will get the machine into supervisor mode
start:

	.global	reset_vector
	.type	reset_vector,function
reset_vector:

	ldr	sp,=__startup_stack

	bl	__low_level_init

warm_reset:

//
// ; copy the vector table (__vector_table_start .. __vector_table_end) to address 0
//
#ifndef USE_HIMO
//  HiMo needs its own exception handlers --> don't overwrite these!!
#if 1
	mov     r8,#0
	ldr     r9,=__exception_handlers
	ldmia   r9!,{r0-r7}
	stmia   r8!,{r0-r7}
	ldmia   r9!,{r0-r7}
	stmia   r8!,{r0-r7}
#else
        ldr	r0,=__vector_table_start
	mov	r1,#0
        ldr	r2,=__vector_table_end
1:
	ldr     r3,[r0],#4
	str     r3,[r1],#4
	cmp     r0,r2
	bcc     1b
#endif
#endif // USE_HIMO

//	; Relocate [copy] data from ROM to RAM
	ldr	r0,=__rom_data_start
	ldr	r1,=__ram_data_start
	ldr	r2,=__ram_data_end
1:
	cmp	r1,r2		//  while (r1 < r2)
	ldrcc	r3,[r0],#4	//  {
	strcc	r3,[r1],#4	//    *r1++ = *r0++;
	bcc	1b		//  }

//	; clear BSS
	ldr	r1,=__bss_start
	ldr	r2,=__bss_end
	mov	r0,#0
1:
	cmp	r1,r2		//; # while (r1 < r2)
	strcc	r0,[r1],#4	//; #   *r1++ = 0;
	bcc	1b

//	; # initialize interrupt/exception environments
	ldr	sp,=__startup_stack
	
	mov	r0,#(CPSR_IRQ_DISABLE|CPSR_FIQ_DISABLE|CPSR_IRQ_MODE)
	msr	cpsr,r0
	ldr	sp,=__interrupt_stack
	
	mov	r0,#(CPSR_IRQ_DISABLE|CPSR_FIQ_DISABLE|CPSR_FIQ_MODE)
	msr	cpsr,r0
	ldr	sp,=__FIQ_exception_stack
	
	mov	r0,#(CPSR_IRQ_DISABLE|CPSR_FIQ_DISABLE|CPSR_UNDEF_MODE)
	msr	cpsr,r0
	ldr	sp,=__exception_stack

//	; # initialize CPSR (machine state register)
	mov	r0,#(CPSR_IRQ_DISABLE|CPSR_FIQ_DISABLE|CPSR_SUPERVISOR_MODE)
	msr	cpsr,r0

//	; # Note: some functions in LIBGCC1 will cause a "restore from SPSR"!!
	msr	spsr,r0

//	; # initialize stack
	ldr	sp,=__startup_stack

// initialize interrupt tables
	bl	IrqInit


#if 1
	ldr	r0,=PxPrepareInit
	cmp	r0,#0
	movne	lr,pc
	movne	pc,r0
#endif


//	; # switch to user mode and enable IRQs
	mov	r0,#(CPSR_FIQ_DISABLE|CPSR_USER_MODE)
	msr	cpsr,r0
	ldr	sp,=__user_stack

        mov     a1,#0                     //; # set argc to 0
        mov     a2,#0                     //; # and argv to NUL
        bl      main
        bl      _exit



//;
//; # Exception handlers
//; # Assumption: get here from a Supervisor context [mode]
//;
	.code	32
undefined_instruction:
	b	undefined_instruction

	.code	32
software_interrupt:
	b	software_interrupt

	.code	32
abort_prefetch:
	b	abort_prefetch

	.code	32
abort_data:
	b	abort_data


	.code	32
FIQ:
        b       FIQ


#define AIC_BASE	0xFFFFF000
#define AIC_IVR_OFFS	0x100		//; IRQ Vector Register
#define AIC_EOICR_OFFS	0x130		//; IEnd of Interrupt Command Register

IRQ:
#if 1
	sub	lr,lr,#4		//; adjust return address before saving it
	str	lr,[sp,#-4]!
	mrs	lr,spsr			//; and status bits
	stmfd	sp!,{r10,r14}		//; push SPSR to allow nested interrupts


//	; switch to SYS mode (to avoid  problem with C language handler code)
	mrs	lr,cpsr			//; read the status register
	bic	lr,lr,#CPSR_MODE_BITS	//; clear the mode bits
	orr	lr,lr,#CPSR_SYSTEM_MODE	//; switch to SYS mode
	msr	cpsr_cf,lr

	stmfd	sp!,{r0-r3,r12,lr}	//; save APCS working register
	adr	lr,Back_From_Handler	//; set the return address
	ldr	r12,=AIC_BASE		//; address table with individual handler
//	; now read-modify-write the CPSR to enable interrupts
	mrs	r0,cpsr			//; read the status register
	bic	r0,r0,#CPSR_IRQ_DISABLE	//; clear the IRQ disable bit
	msr	cpsr_cf,r0		//; reenable interrupts
//	; jump to the correct handler
	ldr	pc,[r12,#AIC_IVR_OFFS]	//; PC base address points to this instruction + 8


Back_From_Handler:
//	; now read-modify-write the CPSR to disable interrupts
	mrs	r0,cpsr			//; read the status register
	orr	r0,r0,#CPSR_IRQ_DISABLE	//; set the IRQ disable bit
	msr	cpsr_cf,r0		//; write it back to disable interrupts

	bic	r10,r0,#CPSR_MODE_BITS	//; clear the mode bits

	ldr	r1,=AIC_BASE		//; signal end of interrupt to AIC
	str	r1,[r1,#AIC_EOICR_OFFS]

	ldmfd	sp!,{r0-r3,r12,lr}	//; restore APCS working register

//	; and switch back to IRQ mode
	orr	r10,r10,#CPSR_IRQ_MODE	//; switch to IRQ mode
	msr	cpsr_cf,r10		//; write it back

	ldmfd	sp!,{r10,lr}		//; Restore rest of registers and get SPSR
	msr	spsr_cf,lr
	ldmfd	sp!,{pc}^		//; and return from interrupt and restore CPSR
#else
	b	IRQ
#endif


#if 1
//; # Dummy/support functions

	.global	__gccmain

__gccmain:
	mov	pc,lr
#endif




//; # -------------------------------------------------------------------------
//; # Interrupt vector tables.
//; # These tables contain the isr, data and object pointers used to deliver
//; # interrupts to user code.

//; # Despite appearances, their sizes are not #defines, but .equ symbols
//; # generated by magic without proper dependencies in arm.inc
//; # Recompiling will not DTRT without manual intervention.

	.data

//; # -------------------------------------------------------------------------
//; # Temporary interrupt stack

        .section ".bss"

	.global	__interrupt_stack

//; # Small stacks, only used for saving information between CPU modes
__exception_stack_base:
        .rept   32
        .long   0
        .endr
__FIQ_exception_stack:
        .rept   32
        .long   0
        .endr
__exception_stack:
#if 0
        .rept   32
        .long   0
        .endr
__undef_exception_stack:
#endif

//; # Runtime stack used during all interrupt processing
	.balign 16
__interrupt_stack_base:
        .rept 2048
        .byte 0
        .endr
	.balign 16
__interrupt_stack:

	.balign 16
__startup_stack_base:
        .rept 2048
        .byte 0
        .endr
	.balign 16
__startup_stack:

	.balign 16
__user_stack_base:
        .rept 2048
        .byte 0
        .endr
	.balign 16
__user_stack:


//; # --------------------------------------------------------------------------
//; #  end of vectors.S
