/********************************************************************************/
/*	FILE 		: MAIN.C						*/
/*										*/
/*	DESCRIPTION 	: FLASH Programing Tool					*/
/*			  for PHYTEC-Board phyCORE-AT91M55800A			*/
/*										*/
/*			  copying data from ram location into			*/		
/*			  flash location. 					*/			  
/*										*/
/*	AUTHOR		: A.Beuscher						*/
/*			  PHYTEC Metechnik GmbH				*/
/*										*/
/*	VERSOIN		: V1.00							*/
/*										*/
/*	DATE		: 12.12.2002						*/
/********************************************************************************/

#include "parts/m55800/m55800.h"
#include "parts/m55800/reg_m55800.h"
#include "drivers/flash/lib_flash_at49.h"
#include "serial.h"

#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <stdarg.h>

#define AT91BV8192A 	4
#define FLASH 		AT91BV8192A
#define FLASHADDRESS 	0x1000000
#define RAMADDRESS	0x4000000

#define COPYSIZE	256*1024

extern const FlashAt49BVDef FlashTable[];

// Function Prototyps


//******************************* start main ***********************************//

int main (void)
	{
	unsigned long Mularray[] = {0x01, 0x10, 0x100, 0x1000, 0x10000, 0x100000, 0x1000000 };
	unsigned char rbuf[10];
	unsigned long x = 0,y;
	FlashAt49BVDef *flash;
	unsigned long flashbaseaddress ,rambaseaddress,address;
	u_short value;
	unsigned char rchar;
	unsigned int flashid;	
	
	init_serial(COM1);
	
	flashbaseaddress = 0;//FLASHADDRESS;
	rambaseaddress = RAMADDRESS;

	at91_printf(COM1,"\r\nPrograming tool for flash of phyCORE-AT91M55800A");
	
	flash = ((FlashAt49BVDef*)&(FlashTable[FLASH]));

	do{
		x = 0x00;
		rchar = 0x00;
		flashbaseaddress = 0x00;
		at91_printf(COM1,"\r\n\n Starting address of flash (e.g.: 1000000 fr 0x1000000 ) : ");		

		do
			{	
			while(!(US0_CSR & US_RXRDY));
			if (US0_RHR != '\r')
				{
				rbuf[x] = US0_RHR; 
				x++;
				}
			}while((US0_RHR != '\r')&& (x < 7));

		if ( x < 7)
			{
			while(!(US0_CSR & US_RXRDY));
				rchar = US0_RHR;
			}
						
		for(y=(x-1);y>0;y--)
			flashbaseaddress = flashbaseaddress + (((rbuf[y])-0x30) * Mularray[(x-1)-y]);
			
		flashbaseaddress = flashbaseaddress + (((rbuf[0])-0x30) * Mularray[(x-1)]);
			
		at91_printf(COM1,"\r\n  Typed address : 0x%x - GO ON ? J/N ",flashbaseaddress);
		
		while(!(US0_CSR & US_RXRDY));
			rchar = US0_RHR;
		 
	} while ((rchar !='J')&&(rchar != 'j'));

		
//	if(flash_at49_identify((u_short*)flashbaseaddress) != 0xA0)

	flashid = flash_at49_identify((u_short*)flashbaseaddress);
	
	if((flashid != 0xCB )&&(flashid != 0x4A )&&(flashid != 0xC0 )&&(flashid != 0xC2 )&&(flashid != 0xA0 )&&(flashid != 0xA3 )
		&&(flashid != 0x5B )&&(flashid != 0xDA )&&(flashid != 0x49 )&&(flashid != 0xC4 )&&(flashid != 0xF9 )&&(flashid != 0xF6 ))
		{
		at91_printf(COM1,"\r\n No flash found - Error !");
	  	return(FALSE);
		}
	else    at91_printf(COM1,"\r\n Flash found at address 0x%X - Erasing !",flashbaseaddress);
	
	flash_at49_erase_flash ( (FlashAt49BVDef*) &(FlashTable[FLASH]) ,(u_short*)flashbaseaddress );	
	
	at91_printf(COM1," Flash erased !\r\n");

	do{
		x = 0x00;
		rchar = 0x00;
		rambaseaddress = 0x00;
		at91_printf(COM1,"\r\n\n Starting adresse of ram (e.g.: 1000000 fr 0x1000000 ) : ");		

		do
			{	
			while(!(US0_CSR & US_RXRDY));
			if (US0_RHR != '\r')
				{
				rbuf[x] = US0_RHR; 
				x++;
				}
			}while((US0_RHR != '\r')&& (x < 7));

		if ( x < 7)
			{
			while(!(US0_CSR & US_RXRDY));
				rchar = US0_RHR;
			}
						
		for(y=(x-1);y>0;y--)
			rambaseaddress = rambaseaddress + (((rbuf[y])-0x30) * Mularray[(x-1)-y]);
			
		rambaseaddress = rambaseaddress + (((rbuf[0])-0x30) * Mularray[(x-1)]);
			
		at91_printf(COM1,"\r\n Typed address : 0x%x - GO ON ? J/N ",rambaseaddress);
		
		while(!(US0_CSR & US_RXRDY));
			rchar = US0_RHR;
		 
	} while ((rchar !='J')&&(rchar != 'j'));

	at91_printf(COM1,"\r\n\n Copying data from 0x%x through 0x%x \r\n", rambaseaddress, flashbaseaddress);
	
	at91_printf(COM1," 0 KB----------------------------------------------------------------%d KB\r\n",(COPYSIZE/1024));
	
	at91_printf(COM1," 0 KB");
	
	for(x=0;x<COPYSIZE/2;x++)
		{
		if((x%(COPYSIZE/128)) == 0)
		   at91_printf(COM1,"-");
		   
		value = *((unsigned long*)(rambaseaddress+(2*x)));
		address = flashbaseaddress+(2*x);
		flash_at49_write_flash((u_short*)flashbaseaddress,(u_short*)address, value);
		}
	at91_printf(COM1,"%d KB", (COPYSIZE/1024));
	
	at91_printf(COM1,"\r\n\n Programming finished");				
		
//	while(1);										
																										
	return (TRUE);
	}
