// #========================================================================
// #
// #    vectors.s
// #
// #    ARM exception vectors
// #
// #========================================================================
// #
// #========================================================================


	.equ	CPSR_IRQ_DISABLE,128
	.equ	CPSR_FIQ_DISABLE,64
	.equ	CPSR_THUMB_ENABLE,32
	.equ	CPSR_IRQ_MODE,18
	.equ	CPSR_FIQ_MODE,17
	.equ	CPSR_USER_MODE,16
	.equ	CPSR_SUPERVISOR_MODE,19
	.equ	CPSR_UNDEF_MODE,27
	.equ	CPSR_MODE_BITS,31


	.file	"vectors.S"


//==========================================================================
//   Hardware exception vectors.
//   This entire section will be copied to location 0x0000 at startup time.
//
	.code	32
	.section ".vectors","ax"
	.global	__exception_handlers
__exception_handlers:
	ldr	pc,.reset_vector		// 0x00
	ldr	pc,.undefined_instruction	// 0x04
	ldr	pc,.software_interrupt		// 0x08 start && software int
	ldr	pc,.abort_prefetch		// 0x0C
	ldr	pc,.abort_data			// 0x10
	.word	0				// unused
	ldr	pc,.IRQ				// 0x18
	ldr	pc,.FIQ				// 0x1C

// The layout of these pointers should match the vector table above since
// they are copied in pairs.
	.global	vectors
vectors:
.reset_vector:
	.word	reset_vector			// 0x20
.undefined_instruction:
	.word	undefined_instruction		// 0x24
.software_interrupt:
	.word	software_interrupt		// 0x28
.abort_prefetch:
	.word	abort_prefetch			// 0x2C
.abort_data:
	.word	abort_data			// 0x30
	.word	0				// 0x34
.IRQ:
	.word	IRQ				// 0x38
.FIQ:
	.word	FIQ				// 0x3c

.start:
	.word	0

// Other vectors
	.balign 16      // Should be at 0x50
	.balign 32

	.text
// Startup code which will get the machine into supervisor mode
	.global	reset_vector
	.type	reset_vector,function
reset_vector:

	ldr	sp,.__startup_stack

	bl	__low_level_init

warm_reset:

	mov     r8,#0
	ldr     r9,=__exception_handlers
	ldmia   r9!,{r0-r7}
	stmia   r8!,{r0-r7}
	ldmia   r9!,{r0-r7}
	stmia   r8!,{r0-r7}

	// Relocate [copy] data from ROM to RAM
	ldr	r0,.__rom_data_start
	ldr	r1,.__ram_data_start
	ldr	r2,.__ram_data_end
1:
	cmp	r1,r2		// while (r1 < r2)
	ldrcc	r3,[r0],#4	// {
	strcc	r3,[r1],#4	//   *r1++ = *r0++;
	bcc	1b		// }

	// clear BSS
	ldr	r1,.__bss_start
	ldr	r2,.__bss_end
	mov	r0,#0
1:
	cmp	r1,r2		// while (r1 < r2)
	strcc	r0,[r1],#4	//   *r1++ = 0;
	bcc	1b

	// initialize interrupt/exception environments
	ldr	sp,.__startup_stack
	mov	r0,#(CPSR_IRQ_DISABLE|CPSR_FIQ_DISABLE|CPSR_IRQ_MODE)
	msr	cpsr,r0
	ldr	sp,.__interrupt_stack
	mov	r0,#(CPSR_IRQ_DISABLE|CPSR_FIQ_DISABLE|CPSR_FIQ_MODE)
	msr	cpsr,r0
	ldr	sp,.__FIQ_exception_stack
	mov	r0,#(CPSR_IRQ_DISABLE|CPSR_FIQ_DISABLE|CPSR_UNDEF_MODE)
	msr	cpsr,r0
	ldr	sp,.__exception_stack

	// initialize CPSR (machine state register)
	mov	r0,#(CPSR_IRQ_DISABLE|CPSR_FIQ_DISABLE|CPSR_SUPERVISOR_MODE)
	msr	cpsr,r0

	// Note: some functions in LIBGCC1 will cause a "restore from SPSR"!!
	msr	spsr,r0

	// initialize stack
	ldr	sp,.__startup_stack

	// switch to user mode and enable IRQs
	mov	r0,#(CPSR_FIQ_DISABLE|CPSR_USER_MODE)
	msr	cpsr,r0
	ldr	sp,.__user_stack

        mov     a1,#0                     // set argc to 0
        mov     a2,#0                     // and argv to NUL
#if 0
        ldr     lr,=main
        mov     pc,lr

_start_hang:
	b	_start_hang
#else
        bl      main
        bl      _exit
#endif
	.code	32



//
// Exception handlers
// Assumption: get here from a Supervisor context [mode]
//
	.code	32
undefined_instruction:
	b	undefined_instruction

	.code	32
software_interrupt:
	b	software_interrupt

	.code	32
abort_prefetch:
	b	abort_prefetch

	.code	32
abort_data:
	b	abort_data


	.code	32
FIQ:
        b       FIQ


IRQ:
#if 0
        stmfd   sp!, {r0-r3,r12,lr} // save APCS work register
        mrs     r0, SPSR            // and status bits
        stmfd   sp!, {r0}

        bl      IrqHandler

        ldmfd   sp!, {r0}           // restore status bits
        msr     SPSR, r0
        ldmfd   sp!, {r0-r3,r12,lr} // and APCS work register
        subs    pc, lr, #4          // return from interrupt
#else
	b	IRQ
#endif


// Dummy/support functions

	.global	__gccmain

__gccmain:
	mov	pc,lr



//
// Pointers to various objects.
//
.__startup_stack:
	.word	__startup_stack
.__interrupt_stack:
	.word	__interrupt_stack
.__user_stack:
	.word	__user_stack
.__FIQ_exception_stack:
	.word	__FIQ_exception_stack
.__exception_stack:
	.word	__exception_stack
.__undef_exception_stack:
	.word	__undef_exception_stack
.__bss_start:
	.word	__bss_start
.__bss_end:
	.word	__bss_end
._end:
	.word	_end
.__rom_data_start:
	.word	__rom_data_start
.__ram_data_start:
	.word	__ram_data_start
.__ram_data_end:
	.word	__ram_data_end
.__exception_handlers:
	.word	__exception_handlers



// -------------------------------------------------------------------------
// Interrupt vector tables.
// These tables contain the isr, data and object pointers used to deliver
// interrupts to user code.

// Despite appearances, their sizes are not #defines, but .equ symbols
// generated by magic without proper dependencies in arm.inc
// Recompiling will not DTRT without manual intervention.

	.data

// -------------------------------------------------------------------------
// Temporary interrupt stack

        .section ".bss"

// Small stacks, only used for saving information between CPU modes
__exception_stack_base:
        .rept   32
        .long   0
        .endr
__FIQ_exception_stack:
        .rept   32
        .long   0
        .endr
__exception_stack:
        .rept   32
        .long   0
        .endr
__undef_exception_stack:

// Runtime stack used during all interrupt processing
	.balign 16
__interrupt_stack_base:
        .rept 2048
        .byte 0
        .endr
	.balign 16
__interrupt_stack:

	.balign 16
__startup_stack_base:
        .rept 512
        .byte 0
        .endr
	.balign 16
__startup_stack:

	.balign 16
__user_stack_base:
        .rept 2048
        .byte 0
        .endr
	.balign 16
__user_stack:


// --------------------------------------------------------------------------
//  end of vectors.S
