/*********************************************************************
    Modul:     Irq.C
    Projekt:
    Zweck:     Verwaltung der IRQ - Interruptserviceroutinen

    Autor:     Willi Thei
    Copyright:

    Stand:     12.07.2001
    12.07.2001 INTMOD in Init setzen
    03.07.2002 Anpassung auf phyCORE-AT91M55800A A.Beuscher
*********************************************************************/

#include "irq.h"
#include "../../../Libs/periph/aic/aic.h"

typedef unsigned char byte;

/*
 * Priority resolution table
 * Index with a bit mask and you get the highest priority in the mask
 * which is set in the mask.  Least significant bit is highest priority.
 */
#define MAXIRQNUM	32
#define IRQ_MAX_NUM     MAXIRQNUM

//static PFV irqVector[IRQ_MAX_NUM];


/*---------------------------------------------------------------------
    Funktion:  IrqInit
    Task:   Initialising - IRQ - handling
    Parameter: void
    return value:  void
---------------------------------------------------------------------*/
void IrqInit(void)
	{
    	int i;
	StructAIC *IRQptr;
	
	IRQptr = AIC_BASE;
	
  	IRQptr->AIC_IDCR = 0xff9fffff;	// disable all interrupts
	IRQptr->AIC_ICCR = 0xff9fffff;	// clear all interrupts
	
//    *INTPND = 0xff9fffff;     /* clear pending interrupts */
//    *INTMSK = 0xff9fffff;     /* mask off all interrupts  */
//    *INTMOD = 0;            /* interrupts mapped to IRQ */

    /* Clear the interrupt vector table in the AIC-registers */
    for (i = 0; i < IRQ_MAX_NUM; ++i)
    {
        IRQptr->AIC_SVR[i] = 0x00;//(PFV) 0;
    }
}

/*---------------------------------------------------------------------
    Function:  	IrqEnable
    Task:	Aktivierung eines bestimmten IRQ-Interruptes
    Parameter: 	int irqNum - Nummer des IRQ-Interruptes
    return value:  void
---------------------------------------------------------------------*/
void IrqEnable(int irqNum)
	{
	StructAIC *IRQptr;
	
	IRQptr = AIC_BASE;
	
    	if ((irqNum < IRQ_MAX_NUM) && (irqNum >= 0))
    		{
    		IRQptr->AIC_IECR |= ( 1 << irqNum );
//#if 0
        /* clear any pending interrupt on that channel */
//        *INTPND  = (1 << irqNum);
//#endif
        /* enable it: force global disable OFF */
//        *INTMSK &= ~((1 << INT_GLOBAL) | (1 << irqNum));
    		}
	}

/*---------------------------------------------------------------------
    Function:  	IrqDisable
    Task:   	Deaktivating IRQ-Interrupt
    Parameter: 	int irqNum - Number of IRQ-Interrupt
    return value:  	void
---------------------------------------------------------------------*/
void IrqDisable(int irqNum)
	{
	StructAIC *IRQptr;
	
	IRQptr = AIC_BASE;
	
    	if ((irqNum < IRQ_MAX_NUM) && (irqNum >= 0))
		IRQptr->AIC_IDCR |= ( 1 << irqNum);
        //	*INTMSK |= (1 << irqNum);
	}

/*---------------------------------------------------------------------
    Function:  IrqInstall
    Task:      Installation of IRQ-Interruptservicehandler
    Parameter: int irqNum  - Number of IRQ-Interrupt
               PFV isrProc - Pointer of Serviceroutine
               int enable  - Flag "Interrupt aktivating"
    return value:  PFV         - Pointer of old ISR-Handler
---------------------------------------------------------------------*/
PFV IrqInstall(int irqNum, PFV isrProc, int enable, int priority)
	{
    	PFV oldIsr;
	StructAIC *IRQptr;
	
	IRQptr = AIC_BASE;

    	if (irqNum < 0 || IRQ_MAX_NUM <= irqNum)
    		{
        	return ((PFV) 0);
    		}

    oldIsr = (PFV)IRQptr->AIC_SVR[irqNum];
//    (PFV)IRQptr->AIC_SMR[irqNum] = AIC_SRCTYPE_INT_EDGE_TRIGGERED;
    (PFV)IRQptr->AIC_SMR[irqNum] = AIC_SRCTYPE_INT_LEVEL_SENSITIVE;
    (PFV)IRQptr->AIC_SVR[irqNum] = isrProc;
    if (enable)
    {
        IrqEnable(irqNum);
    }

    return (oldIsr);
}

/*---------------------------------------------------------------------
    Function:  	  IrqHandler
    Task:   	  Verwaltungsprozedur fr IRQ-Interrupts
    Parameter: 	  void
    retun value:  void
---------------------------------------------------------------------*/
/*void IrqHandler(void)
{
    unsigned int rq, rq1;
    PFV  isr;

    rq  = *INTPND & 0x01FFFFF;

    // Aufteilung auf 3 Bytes (wg. Gre von unmapTbl) 
    rq1 = rq & 0xFF;

    if (rq1 != 0)
    {
        isr = irqVector[unmapTbl[rq1]];
        if (isr)
        {
            (*(isr))();
        }
        return;
    }

    rq >>= 8;
    rq1 = rq & 0xFF;
    if (rq1 != 0)
    {
        isr = irqVector[unmapTbl[rq1]+8];
        if (isr)
        {
            (*(isr))();
        }
        return;
    }

    rq >>= 8;
    if (rq != 0)
    {
        isr = irqVector[unmapTbl[rq]+16];
        if (isr)
        {
            (*(isr))();
        }
        return;
    }

}*/
