//*-----------------------------------------------------------------------------
//*      ATMEL Microcontroller Software Support  -  ROUSSET  -
//*-----------------------------------------------------------------------------
//* The software is delivered "AS IS" without warranty or condition of any
//* kind, either express, implied or statutory. This includes without
//* limitation any warranty or condition with respect to merchantability or
//* fitness for any particular purpose, or against the infringements of
//* intellectual property rights of others.
//*-----------------------------------------------------------------------------
//* File Name           : flash_at49_data.c
//* Object              : FLASH description for :
//*
//* 1.0 02/11/00 JPP    : Creation
//*-----------------------------------------------------------------------------

#include    "lib_flash_at49.h"
//* Global Variable

/* Defines supported flash organizations */
const OrgDef OrgAT49BV8011[] =
{
    /* 1 x 16kbytes sectors */
    {
        1,
        16*1024
    },
    /* 1 x 32 kbytes sectors */
    {
        1,
        32*1024,
    },
    /* 4 x 8 kbytes sectors */
    {
        4,
        8*1024,
    },
    /* 1 x 32 kbytes sectors */
    {
        1,
        32*1024,
    },
    /* 1 x 16kbytes sectors */
    {
        1,
        16*1024
    },
    /* 14 x 64 kbytes sectors */
    {
        14,
        64*1024,
    }
};

const OrgDef OrgAT49BV8011T[] =
{
    /* 14 x 64 kbytes sectors */
    {
        14,
        64*1024,
    },
    /* 1 x 16kbytes sectors */
    {
        1,
        16*1024
    },
    /* 1 x 32 kbytes sectors */
    {
        1,
        32*1024,
    },
    /* 4 x 8 kbytes sectors */
    {
        4,
        8*1024,
    },
    /* 1 x 32 kbytes sectors */
    {
        1,
        32*1024,
    },
    /* 1 x 16kbytes sectors */
    {
        1,
        16*1024
    }
};

const OrgDef OrgAT49BV16x4[] =
{
    /* 8 x 8kbytes sectors */
    {
        8,
        8*1024
    },
    /* 2 x 32 kbytes sectors */
    {
        2,
        32*1024,
    },
    /* 30 x 64 kbytes sectors */
    {
        30,
        64*1024,
    }
};

const OrgDef OrgAT49BV16x4T[] =
{
    /* 30 x 64 kbytes sectors */
    {
        30,
        64*1024,
    },
    /* 2 x 32 kbytes sectors */
    {
        2,
        32*1024,
    },
    /* 8 x 8kbytes sectors */
    {
        8,
        8*1024
    }
};

const OrgDef OrgAT49BV8192A[] =
{
    /* 1 x 8 kbytes sectors */
    {
        1,
        8*1024
    },
    /* 2 x 4 kbytes sectors */
    {
        2,
        4*1024,
    },
    /* 1 x 992 kbytes sectors */
    {
        1,
        992*1024,
    }
};

const OrgDef OrgAT49BV8192AT[] =
{
    /* 1 x 992 kbytes sectors */
    {
        1,
        992*1024
    },
    /* 2 x 4 kbytes sectors */
    {
        2,
        4*1024,
    },
    /* 1 x 8 kbytes sectors */
    {
        1,
        8*1024,
    }
};

/************************** neue Flash Typen fr PL1192.1 *******************/

const OrgDef OrgAM29LV800BB[] =
{
    /* 1 x 16kbytes sectors */
    {
        1,
        16*1024
    },
    /* 2 x 8 kbytes sectors */
    {
        2,
        8*1024,
    },
    /* 1 x 32 kbytes sectors */
    {
        1,
        32*1024,
    },
    /* 15 x 64 kbytes sectors */
    {
    	15,
	64*1024
    }
    
};

const OrgDef OrgAM29LV800BT[] =
{
    /* 15 x 64 kbytes sectors */
    {
        15,
        64*1024,
    },
    /* 1 x 32 kbytes sectors */
    {
        1,
        32*1024,
    },
    /* 2 x 8kbytes sectors */
    {
        2,
        8*1024
    },
    /* 1 x 16kbytes sectors */    
    {
        1,
        16*1024
    }    
};

const OrgDef OrgAM29LV160BB[] =
{
    /* 1 x 16kbytes sectors */
    {
        1,
        16*1024
    },
    /* 2 x 8 kbytes sectors */
    {
        2,
        8*1024,
    },
    /* 1 x 32 kbytes sectors */
    {
        1,
        32*1024,
    },
    /* 15 x 64 kbytes sectors */
    {
    	31,
	64*1024
    }
    
};

const OrgDef OrgAM29LV160BT[] =
{
    /* 15 x 64 kbytes sectors */
    {
        31,
        64*1024,
    },
    /* 1 x 32 kbytes sectors */
    {
        1,
        32*1024,
    },
    /* 2 x 8kbytes sectors */
    {
        2,
        8*1024
    },
    /* 1 x 16kbytes sectors */    
    {
        1,
        16*1024
    }    
};
const OrgDef OrgAM29LV320DB[] =
{
    /* 8 x 8 kbytes sectors */
    {
        8,
        8*1024,
    },
    /* 15 x 64 kbytes sectors */
    {
    	62,
	64*1024
    }
    
};

const OrgDef OrgAM29LV320DT[] =
{
    /* 15 x 64 kbytes sectors */
    {
        62,
        64*1024,
    },
    /* 8 x 8kbytes sectors */
    {
        8,
        8*1024
    }

};



/************************** Ende neue Flash Typen **************/


/* Define supported flash Table */
const FlashAt49BVDef FlashTable[NB_FLASH_SUPPORTED] =
{
    {
        1024*1024,                  /* 1 M Bytes */
        "AT49BV8011",
        ATMEL_MANUFACTURED,
        FLASH_AT49BV8011,
        0x000FFFFF,
        (OrgDef*)OrgAT49BV8011,
        sizeof(OrgAT49BV8011)/sizeof(OrgDef)
    },
    {
        1024*1024,                  /* 1 M Bytes */
        "AT49BV8011",
        ATMEL_MANUFACTURED,
        FLASH_AT49BV8011T,
        0x000FFFFF,
        (OrgDef*)OrgAT49BV8011T,
        sizeof(OrgAT49BV8011T)/sizeof(OrgDef)
    },
    {
        2*1024*1024,                /* 2 M Bytes */
        "AT49BV16x4",
        ATMEL_MANUFACTURED,
        FLASH_AT49BV16x4,
        0x001FFFFF,
        (OrgDef*)OrgAT49BV16x4,
        sizeof(OrgAT49BV16x4)/sizeof(OrgDef)
    },
    {
        2*1024*1024,                /* 2 M Bytes */
        "AT49BV16x4T",
        ATMEL_MANUFACTURED,
        FLASH_AT49BV16x4T,
        0x001FFFFF,
        (OrgDef*)OrgAT49BV16x4T,
        sizeof(OrgAT49BV16x4T)/sizeof(OrgDef)
    },
    {
        1024*1024,                /* 1 M Bytes */
        "AT49BV8192A",
        ATMEL_MANUFACTURED,
        FLASH_AT49BV8192A,
        0x000FFFFF,
        (OrgDef*)OrgAT49BV8192A,
        sizeof(OrgAT49BV8192A)/sizeof(OrgDef)
    },
    {
        1024*1024,                /* 1 M Bytes */
        "AT49BV8192AT",
        ATMEL_MANUFACTURED,
        FLASH_AT49BV8192AT,
        0x000FFFFF,
        (OrgDef*)OrgAT49BV8192AT,
        sizeof(OrgAT49BV8192AT)/sizeof(OrgDef)
    },
        {
        1024*1024,                /* 1 M Bytes */
        "AM29LV800BB",
        AMD_MANUFACTURED,
        FLASH_AM29LV800BB,
        0x000FFFFF,
        (OrgDef*)OrgAM29LV800BB,
        sizeof(OrgAM29LV800BB)/sizeof(OrgDef)
    },
    {
        1024*1024,                /* 1 M Bytes */
        "AM29LV800BT",
        AMD_MANUFACTURED,
        FLASH_AM29LV800BT,
        0x000FFFFF,
        (OrgDef*)OrgAM29LV800BT,
        sizeof(OrgAM29LV800BT)/sizeof(OrgDef)
    },
    {
        2*1024*1024,                /* 2 M Bytes */
        "AM29LV160BB",
        AMD_MANUFACTURED,
        FLASH_AM29LV160BB,
        0x001FFFFF,
        (OrgDef*)OrgAM29LV160BB,
        sizeof(OrgAM29LV160BB)/sizeof(OrgDef)
    },
    {
        2*1024*1024,                /* 2 M Bytes */
        "AM29LV160BT",
        AMD_MANUFACTURED,
        FLASH_AM29LV160BT,
        0x001FFFFF,
        (OrgDef*)OrgAM29LV160BT,
        sizeof(OrgAM29LV160BT)/sizeof(OrgDef)
    },
    {
        4*1024*1024,                /* 4 M Bytes */
        "AM29LV320DB",
        AMD_MANUFACTURED,
        FLASH_AM29LV320DB,
        0x003FFFFF,
        (OrgDef*)OrgAM29LV320DB,
        sizeof(OrgAM29LV320DB)/sizeof(OrgDef)
    },
    {
        4*1024*1024,                /* 2 M Bytes */
        "AM29LV320DT",
        AMD_MANUFACTURED,
        FLASH_AM29LV320DT,
        0x003FFFFF,
        (OrgDef*)OrgAM29LV320DT,
        sizeof(OrgAM29LV320DT)/sizeof(OrgDef)
    },



};

//* End
