//*-----------------------------------------------------------------------------
//*      ATMEL Microcontroller Software Support  -  ROUSSET  -
//*-----------------------------------------------------------------------------
//* The software is delivered "AS IS" without warranty or condition of any
//* kind, either express, implied or statutory. This includes without
//* limitation any warranty or condition with respect to merchantability or
//* fitness for any particular purpose, or against the infringements of
//* intellectual property rights of others.
//*-----------------------------------------------------------------------------
//* File Name           : lib_i2c.c
//* Object              : I2C driver functions
//*
//* 1.0 29/05/00  EL    : Creation
//* 2.0 06/09/00  EL    : Clean up
//* 2.1 21/11/00  JPP   : Change Timer interrupt in LEVEL
//*-----------------------------------------------------------------------------

#include    "periph/timer_counter/lib_tc.h"
#include    "lib_i2c.h"
#include    "periph/power_saving/lib_power_save.h"

extern void no_handler_tc(I2Cdesc *I2C_pt);
extern void at91_I2CError(I2Cdesc *I2C_pt);

//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CWrite (I2Cdesc *I2C_pt, u_short loadAddress, u_char nbByte)
//* Object              : I2C
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//*			: loadAddress
//*			: nbByte
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CWrite (I2Cdesc *I2C_pt, u_short loadAddress, u_int nbByte)
//* Begin
{
    //* initialize state
    I2C_pt->state = NOK;

    //* set SDA line as an output
    I2C_pt->pioa_base->PIO_OER = I2C_pt->SDA_line;

    //* set SCL line as an output
    I2C_pt->pioa_base->PIO_OER = I2C_pt->SCL_line;

    //* set SCL line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SCL_line;

    //* set SDA line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SDA_line;

    //* get byte to transmit
    I2C_pt->I2CByte = I2C_pt->deviceAddress | WRITE_BIT | 0xA0;

    //* get address
    I2C_pt->loadAddress = loadAddress;

    //* next mode
    I2C_pt->mode = HIGH_ADDRESS_WRITE;

    //* get nb byte to transmit
    I2C_pt->nbI2CByte = nbByte;

    //* initialize countBit
    I2C_pt->countBit = 8;

    //* initialize nb_ACK
    I2C_pt->nb_ACK = 10;

    //* change interrupt handler to at91_I2CTxSendStartSDA
    I2C_pt->I2CTCHandler = at91_I2CTxSendStartSDA;

     //* Enable RC compare interrupt
    I2C_pt->timerBase->TC_IER = TC_CPCS;

//* End
}
//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CRead (I2Cdesc *I2C_pt, u_short loadAddress, u_char nbByte)
//* Object              : I2C
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//*			: loadAddress
//*			: nbByte
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CRead (I2Cdesc *I2C_pt, u_short loadAddress, u_int nbByte)
//* Begin
{

    //* initialize state
    I2C_pt->state = NOK;

    //* set SDA line as an output
    I2C_pt->pioa_base->PIO_OER = I2C_pt->SDA_line;

    //* set SCL line as an output
    I2C_pt->pioa_base->PIO_OER = I2C_pt->SCL_line;

    //* set SCL line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SCL_line;

    //* set SDA line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SDA_line;

    //* get byte to read
    I2C_pt->I2CByte = I2C_pt->deviceAddress | WRITE_BIT | 0xA0;

    //* get address
    I2C_pt->loadAddress = loadAddress;

    //* next mode
    I2C_pt->mode = HIGH_ADDRESS_READ;

    //* get nb byte to transmit
    I2C_pt->nbI2CByte = nbByte;

    //* initialize countBit
    I2C_pt->countBit = 8;

    //* initialize nb_ACK
    I2C_pt->nb_ACK = 10;

    //* change interrupt handler to at91_I2CTxSendStartSDA
    I2C_pt->I2CTCHandler = at91_I2CTxSendStartSDA;

     //* Enable RC compare interrupt
    I2C_pt->timerBase->TC_IER = TC_CPCS;

//* End
}

//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2C (I2Cdesc *I2C_pt, u_short loadAddress, u_char nbByte)
//* Object              : I2C
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//*			: loadAddress
//*			: nbByte
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CDeviceRead (I2Cdesc *I2C_pt)
//* Begin
{
    //* set SDA line as an output
    I2C_pt->pioa_base->PIO_OER = I2C_pt->SDA_line;

    //* set SDA line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SDA_line;

    //* set SCL line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SCL_line;

    //* get byte to transmit
    I2C_pt->I2CByte = I2C_pt->deviceAddress | READ_BIT | 0xA0;

    //* next mode
    I2C_pt->mode = DATA_READ;

    //* initialize countBit
    I2C_pt->countBit = 8;

    //* initialize nb_ACK
    I2C_pt->nb_ACK = 10;

    //* change interrupt handler to at91_I2CTxSendStartSDA
    I2C_pt->I2CTCHandler = at91_I2CTxSendStartSDA;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CTxSendByte (I2Cdesc *I2C_pt)
//* Object              : I2C
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CTxSendByte (I2Cdesc *I2C_pt)
//* Begin
{
    //* set SDA line as an output
    I2C_pt->pioa_base->PIO_OER = I2C_pt->SDA_line;

    //* set SDA line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SDA_line;


    //* get byte to transmit
    switch(I2C_pt->mode)
    {
	case DATA :
	    I2C_pt->I2CByte = *(I2C_pt->TxEnd++);

	    I2C_pt->nbI2CByte--;
	    if(I2C_pt->nbI2CByte == 0)
	        //* next mode
                I2C_pt->mode = STOP;
	    break;

	case HIGH_ADDRESS_WRITE :
	    I2C_pt->I2CByte = (u_char) (I2C_pt->loadAddress >> 8);

            //* next mode
            I2C_pt->mode = LOW_ADDRESS_WRITE;
	    break;

	case LOW_ADDRESS_WRITE :
	    I2C_pt->I2CByte = (u_char) I2C_pt->loadAddress;

	    //* next mode
	    I2C_pt->mode = DATA;
	    break;

	case HIGH_ADDRESS_READ :
	    I2C_pt->I2CByte = (u_char) (I2C_pt->loadAddress >> 8);

            //* next mode
            I2C_pt->mode = LOW_ADDRESS_READ;
	    break;

	case LOW_ADDRESS_READ :
	    I2C_pt->I2CByte = (u_char) I2C_pt->loadAddress;

	    //* next mode
	    I2C_pt->mode = DEVICE_READ;
	    break;
    }

    //* initialize countBit
    I2C_pt->countBit = 8;

    //* initialize nb_ACK
    I2C_pt->nb_ACK = 10;

    //* change interrupt handler to at91_I2CTxSendBit
    I2C_pt->I2CTCHandler = at91_I2CTxSendBit;


//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CTxSendBit (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CTxSendBit (I2Cdesc *I2C_pt)
//* Begin
{
    u_char bit_val;

     //* Clear SCL line
    I2C_pt->pioa_base->PIO_CODR = I2C_pt->SCL_line;

    //* decrement countBit
    I2C_pt->countBit--;

    //* if bit counter = 0
    if(I2C_pt->countBit >= 0)
    {
	//* get bit to transfert
	bit_val = (I2C_pt->I2CByte >> I2C_pt->countBit) & 1;

	//* Send 0 or 1
	if (bit_val)
   	    //* Set SDA line
	    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SDA_line;

        else
	    //* Clear SDA line
	    I2C_pt->pioa_base->PIO_CODR = I2C_pt->SDA_line;

 	//* change interrupt handler to at91_I2CTxSetSCL
	I2C_pt->I2CTCHandler = at91_I2CTxSetSCL;
    }
    else
    {
   	//* set SDA line as an input
	I2C_pt->pioa_base->PIO_ODR = I2C_pt->SDA_line;

	//* change interrupt handler to at91_I2CTxPrepareACK
	I2C_pt->I2CTCHandler = at91_I2CTxPrepareACK;
    }
//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CTxSendStartSDA (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CTxSendStartSDA (I2Cdesc *I2C_pt)
//* Begin
{
    //* clear SDA line
    I2C_pt->pioa_base->PIO_CODR = I2C_pt->SDA_line;

    //* change interrupt handler to at91_I2CTxSendStartSCL
    I2C_pt->I2CTCHandler = at91_I2CTxSendStartSCL;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CTxSendStart (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CTxSendStartSCL (I2Cdesc *I2C_pt)
//* Begin
{
    //* clear SCL line
    I2C_pt->pioa_base->PIO_CODR = I2C_pt->SCL_line;

    //* change interrupt handler to at91_I2CTxSendBit
    I2C_pt->I2CTCHandler = at91_I2CTxSendBit;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CTxPrepareSTOP (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CTxPrepareSTOP (I2Cdesc *I2C_pt)
//* Begin
{
    //* set SDA line as an output
    I2C_pt->pioa_base->PIO_OER = I2C_pt->SDA_line;

    //* clear SDA line
    I2C_pt->pioa_base->PIO_CODR = I2C_pt->SDA_line;

    //* set SCL line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SCL_line;

    //* change interrupt handler to at91_I2CTxSendStopSDA
    I2C_pt->I2CTCHandler = at91_I2CTxSendStopSDA;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CTxSendStopSCL (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CTxSendStopSCL (I2Cdesc *I2C_pt)
//* Begin
{
    //* set SCL line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SCL_line;

    //* change interrupt handler to at91_I2CTxSendStopSDA
    I2C_pt->I2CTCHandler = at91_I2CTxSendStopSDA;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CTxSendStopSDA (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CTxSendStopSDA (I2Cdesc *I2C_pt)
//* Begin
{
    //* set SDA line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SDA_line;

    I2C_pt->state = OK;

    //* Disable RC compare interrupt
    I2C_pt->timerBase->TC_IDR = TC_CPCS;

    //* change interrupt handler to
    I2C_pt->I2CTCHandler = no_handler_tc;


//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CTxPrepareACK (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CTxPrepareACK (I2Cdesc *I2C_pt)
//* Begin
{
    //* set SCL line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SCL_line;

    //* change interrupt handler to at91_I2CTxWaitACK
    I2C_pt->I2CTCHandler = at91_I2CTxWaitACK;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CRxPrepareACK (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CRxPrepareACK (I2Cdesc *I2C_pt)
//* Begin
{
    //* set SCL line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SCL_line;

    if(I2C_pt->mode == STOP)
        //* change interrupt handler to
        I2C_pt->I2CTCHandler = at91_I2CTxPrepareSTOP;

    else
        //* change interrupt handler to at91_I2CRxDoACK
        I2C_pt->I2CTCHandler = at91_I2CRxDoACK;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CTxWaitACK (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CTxWaitACK (I2Cdesc *I2C_pt)
//* Begin
{
    //* if ACK (SDA = 0)
    if((I2C_pt->pioa_base->PIO_PDSR & I2C_pt->SDA_line) == 0)
    {

	switch(I2C_pt->mode)
	{
	    case STOP :
		//* clear SCL line
		I2C_pt->pioa_base->PIO_CODR = I2C_pt->SCL_line;

	        //* change interrupt handler to
	        I2C_pt->I2CTCHandler = at91_I2CTxPrepareSTOP;
		break;

	    case DEVICE_READ :
		//* clear SCL line
		I2C_pt->pioa_base->PIO_CODR = I2C_pt->SCL_line;

		//* change interrupt handler to
	        I2C_pt->I2CTCHandler = at91_I2CDeviceRead;
		break;


	    case DATA_READ :
		//* change interrupt handler to
	        I2C_pt->I2CTCHandler = at91_I2CRxReceiveByte;
		break;

	    default :
		//* clear SCL line
		I2C_pt->pioa_base->PIO_CODR = I2C_pt->SCL_line;

		//* change interrupt handler to
		I2C_pt->I2CTCHandler = at91_I2CTxSendByte;
		break;
	}
    }
    else
    {
        I2C_pt->nb_ACK--;
	if(I2C_pt->nb_ACK == 0)
	    //* change interrupt handler to at91_I2C
	    I2C_pt->I2CTCHandler = at91_I2CError;
   }
//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CRxDoACK (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CRxDoACK (I2Cdesc *I2C_pt)
//* Begin
{
    //* clear SCL line
    I2C_pt->pioa_base->PIO_CODR = I2C_pt->SCL_line;

    //* change interrupt handler to
    I2C_pt->I2CTCHandler = at91_I2CRxReceiveByte;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CTxSetSCL (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CTxSetSCL (I2Cdesc *I2C_pt)
//* Begin
{
    //* set SCL line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SCL_line;

    //* change interrupt handler to at91_I2CTxSendBit
     I2C_pt->I2CTCHandler = at91_I2CTxSendBit;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CTxClearSCL (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CTxClearSCL (I2Cdesc *I2C_pt)
//* Begin
{
    //* Clear SCL line
    I2C_pt->pioa_base->PIO_CODR = I2C_pt->SCL_line;

    if(I2C_pt->countBit == 0)
    	//* set SDA line as an input
	I2C_pt->pioa_base->PIO_ODR = I2C_pt->SDA_line;

    //* change interrupt handler to at91_I2CTxSendBit
    I2C_pt->I2CTCHandler = at91_I2CTxSendBit;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CRxSetSCL (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CRxSetSCL (I2Cdesc *I2C_pt)
//* Begin
{
    //* set SCL line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SCL_line;

    //* change interrupt handler to at91_I2CRxReceiveBit
    I2C_pt->I2CTCHandler = at91_I2CRxReceiveBit;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CRxClearSCL (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CRxClearSCL (I2Cdesc *I2C_pt)
//* Begin
{
    //* Clear SCL line
    I2C_pt->pioa_base->PIO_CODR = I2C_pt->SCL_line;

    if(I2C_pt->countBit == 0)
      {
	    //* change interrupt handler to at91_I2CI2CRxPrepareACK
  	    I2C_pt->I2CTCHandler = at91_I2CRxPrepareACK;

            //* set SDA line as an output
	    I2C_pt->pioa_base->PIO_OER = I2C_pt->SDA_line;

	    //* clear SDA line
 	    I2C_pt->pioa_base->PIO_CODR = I2C_pt->SDA_line;
      }
    else
	//* change interrupt handler to at91_I2CRx
	I2C_pt->I2CTCHandler = at91_I2CRxReceiveBit;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : at91_I2CRxReceiveByte (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CRxReceiveByte (I2Cdesc *I2C_pt)
//* Begin
{
	//* set SDA line as an input
	I2C_pt->pioa_base->PIO_ODR = I2C_pt->SDA_line;

	//* clear SCL line
	I2C_pt->pioa_base->PIO_CODR = I2C_pt->SCL_line;

	//* initialize countBit
	I2C_pt->countBit = 8;

        I2C_pt->nbI2CByte--;
        if(I2C_pt->nbI2CByte == 0)
            //* next mode
            I2C_pt->mode = STOP;

	//* change interrupt handler to at91_I2C
	I2C_pt->I2CTCHandler = at91_I2CRxReceiveBit;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : u_char at91_I2CRxReceiveBit (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void at91_I2CRxReceiveBit (I2Cdesc *I2C_pt)
//* Begin
{
	u_char bit_val;

        //* set SCL line
        I2C_pt->pioa_base->PIO_SODR = I2C_pt->SCL_line;

	//* decrement countBit
	I2C_pt->countBit--;

	//* get bit
	if((I2C_pt->pioa_base->PIO_PDSR & I2C_pt->SDA_line) == I2C_pt->SDA_line)
	    bit_val = 1;
	else
	    bit_val = 0;

	//* if bit counter > 0
	if(I2C_pt->countBit > 0)
	    //* update working byte
	    *I2C_pt->RxEnd |= (bit_val << I2C_pt->countBit);

	else
	     *(I2C_pt->RxEnd++) |= (bit_val << I2C_pt->countBit) ;

    //* change interrupt handler to at91_I2CRxClearSCL
    I2C_pt->I2CTCHandler = at91_I2CRxClearSCL;

//* End
}


//*-----------------------------------------------------------------------------
//* Function Name       : u_char at91_I2CRxReceiveBit (I2Cdesc *I2C_pt)
//* Object              :
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void I2C_lineHandlerInt (I2Cdesc *I2C_pt)
{
u_char dummy;
    //* acknowledge interrupt status
    dummy = I2C_pt->timerBase->TC_SR;


    //* call automate state handler*/
    (*(I2C_pt->I2CTCHandler))(I2C_pt);
}


//*-----------------------------------------------------------------------------
//* Function Name       :  (I2Cdesc *I2C_pt)
//* Object              : I2C
//* Input Parameters    : <I2C_pt> = I2C Peripheral Descriptor pointer
//* Output Parameters   : none
//*-----------------------------------------------------------------------------
void I2C_lineOpen (I2Cdesc *I2C_pt, u_int RCValue)
//* Begin
{
    //* line
    I2C_pt->state = OK;

    //* set SDA line as an output
    I2C_pt->pioa_base->PIO_OER = I2C_pt->SDA_line;

    //* set SDA line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SDA_line;

    //* set SCL line as an output
    I2C_pt->pioa_base->PIO_OER = I2C_pt->SCL_line;

    //* set SCL line
    I2C_pt->pioa_base->PIO_SODR = I2C_pt->SCL_line;


    at91_clock_open(I2C_pt->pio_ctrl_desc->periph_id);

    //* TIMER configuration
    //* Set the mode of the timer
    //* Open the clock of the timer
    at91_clock_open(I2C_pt->channelId);

    I2C_pt->timerBase->TC_CMR = 0x0000C400;
    I2C_pt->timerBase->TC_RC = RCValue;
	//* modificationn set in LEVEL not EDGE
    at91_irq_open(I2C_pt->channelId, 7, AIC_SRCTYPE_INT_LEVEL_SENSITIVE, I2C_pt->AICHandler);

    //* Enable the clock
    I2C_pt->timerBase->TC_CCR = TC_CLKEN;


//* End
}




