//*----------------------------------------------------------------------------
//*         ATMEL Microcontroller Software Support  -  ROUSSET  -
//*----------------------------------------------------------------------------
//* The software is delivered "AS IS" without warranty or condition of any
//* kind, either express, implied or statutory. This includes without
//* limitation any warranty or condition with respect to merchantability or
//* fitness for any particular purpose, or against the infringements of
//* intellectual property rights of others.
//*----------------------------------------------------------------------------
//* File Name           : lib_i2c.h
//* Object              : I2C driver Function Prototyping File.
//*
//* 1.0 25/05/00 EL     : Creation
//* 1.1 06/09/00 EL		: Clean up
//*----------------------------------------------------------------------------

#ifndef lib_i2c_h
#define lib_i2c_h

#include    "periph/pio/lib_pio.h"
#include    "periph/timer_counter/lib_tc.h"

#define I2C_MASTER 0
#define I2C_SLAVE  1

#define WRITE_BIT    0
#define READ_BIT     1
#define STOP  	     2
#define DATA         3
#define LOW_ADDRESS_WRITE  4
#define HIGH_ADDRESS_WRITE 5
#define LOW_ADDRESS_READ   6
#define HIGH_ADDRESS_READ  7
#define DEVICE_READ    8
#define DATA_READ    9

#define OK  0
#define NOK 1

typedef struct I2C
{
   //* Buffers
    u_char *RxBase;
    u_char *RxPtr;
    u_char *RxEnd;
    u_char *TxPtr;
    u_char *TxEnd;

    //* work variables
    u_char deviceAddress;
    u_short loadAddress; 
    u_char nb_ACK;
    u_int nbI2CByte;
    u_char mode;
    signed char countBit;
    u_char I2CByte;
    volatile u_char  state;

    //* PIO field
    StructPIO *pioa_base;
    const PioCtrlDesc   *pio_ctrl_desc ;
    u_int SDA_line;
    u_int SCL_line;
	
    //* Timer Counter field
    StructTCBlock *TCBase;
    StructTC *timerBase;
    u_char channelId; 

    //* IRQ field
    TypeAICHandler *AICHandler;
    void (*I2CTCHandler) (struct I2C *);

 
} I2Cdesc ; 

extern void  I2C_lineHandlerInt(I2Cdesc *I2C_pt);
extern void  I2C_lineOpen(I2Cdesc *I2C_pt, u_int RCValue);

extern void at91_I2CWrite (I2Cdesc *I2C_pt, u_short loadAddress, u_int nbByte);
extern void at91_I2CRead (I2Cdesc *I2C_pt, u_short loadAddress, u_int nbByte);

extern void  at91_I2CTxSendByte (I2Cdesc *I2C_pt);
extern void  at91_I2CTxSendDeviceAddress (I2Cdesc *I2C_pt);
extern void  at91_I2CTxSendBit (I2Cdesc *I2C_pt);
extern void  at91_I2CRxReceiveByte (I2Cdesc *I2C_pt);
extern void  at91_I2CRxReceiveBit (I2Cdesc *I2C_pt);

extern void  at91_I2CTxSendStartSDA (I2Cdesc *I2C_pt);
extern void  at91_I2CTxSendStartSCL (I2Cdesc *I2C_pt);
extern void  at91_I2CTxPrepareSTOP (I2Cdesc *I2C_pt);
extern void  at91_I2CTxSendStopSCL (I2Cdesc *I2C_pt);
extern void  at91_I2CTxSendStopSDA (I2Cdesc *I2C_pt);
extern void  at91_I2CTxPrepareACK (I2Cdesc *I2C_pt);
extern void  at91_I2CTxWaitACK (I2Cdesc *I2C_pt);
extern void  at91_I2CRxDoACK (I2Cdesc *I2C_pt);

extern void  at91_I2CTxSetSCL (I2Cdesc *I2C_pt);
extern void  at91_I2CTxClearSCL (I2Cdesc *I2C_pt);
extern void  at91_I2CRxSetSCL (I2Cdesc *I2C_pt);
extern void  at91_I2CRxClearSCL (I2Cdesc *I2C_pt);



#endif /* lib_i2c_h */
