;------------------------------------------------------------------------------
;-         ATMEL Microcontroller Software Support  -  ROUSSET  -
;------------------------------------------------------------------------------
; The software is delivered "AS IS" without warranty or condition of any
; kind, either express, implied or statutory. This includes without
; limitation any warranty or condition with respect to merchantability or
; fitness for any particular purpose, or against the infringements of
; intellectual property rights of others.
;------------------------------------------------------------------------------
;- File Name            : m40400.inc
;- Object               : AT91M40400 Definition File.
;-
;- 1.0 01/04/00 JCZ     : Creation
;- 1.1 02/11/00 JPP     : Green Hills
;------------------------------------------------------------------------------

;--------------------------------------
;-  Peripheral Identifier and Interrupt
;--------------------------------------

FIQ_ID          EQU     0       ;- Fast Interrupt 
SWIRQ_ID        EQU     1       ;- Soft Interrupt (generated by the AIC) 
US0_ID          EQU     2       ;- USART Channel 0 
US1_ID          EQU     3       ;- USART Channel 1 
TC0_ID          EQU     4       ;- Timer Channel 0
TC1_ID          EQU     5       ;- Timer Channel 1
TC2_ID          EQU     6       ;- Timer Channel 2
WD_ID           EQU     7       ;- Watchdog
PIO_ID          EQU     8       ;- Parallel I/O Controller

IRQ0_ID         EQU     16      ;- External interrupt 0 
IRQ1_ID         EQU     17      ;- External interrupt 1 
IRQ2_ID         EQU     18      ;- External interrupt 2 


;------------------------
;- Peripheral Memory Map
;------------------------

WD_BASE         EQU     0xFFFF8000      ;- WD: Watchdog Timer
PIO_BASE        EQU     0xFFFF0000      ;- Parallel I/O Controller B
TCB_BASE        EQU     0xFFFE0000      ;- Channels 0, 1, 2
TC0_BASE        EQU     0xFFFE0000      ;- Timer Counter Channel 0
TC1_BASE        EQU     0xFFFE0040      ;- Timer Counter Channel 1
TC2_BASE        EQU     0xFFFE0080      ;- Timer Counter Channel 2
USART1_BASE     EQU     0xFFFCC000      ;- USART 1
USART0_BASE     EQU     0xFFFD0000      ;- USART 0

;----------------------------------
; Internal Memory Mapping and Size
;----------------------------------

RAM_BASE        EQU     0
RAM_SIZE        EQU     (4*1024)
RAM_LIMIT       EQU     (RAM_BASE+RAM_SIZE)

;- The internal RAM is mapped at address 0x00300000 after reset until
;-   Remap command is performed on the EBI. 

RAM_BASE_BOOT   EQU     0x00300000

;---------------------
; ARM Core : ARM7TDMI
;---------------------
        INCLUDE         ../../periph/arm7tdmi/arm.inc

;-----------------------------
;- Special Function Registers
;-----------------------------
        INCLUDE         ../../periph/special_function/sf.inc

;-----------------------
;External Bus Interface
;-----------------------
        INCLUDE         ../../periph/ebi/ebi.inc

;-----------------------------
; Power Management Controller
;-----------------------------
        INCLUDE         ../../periph/power_saving/ps40400.inc

;-------------------------------------------------
; AIC Interrupt Sources and peripheral Identifier
;-------------------------------------------------
        INCLUDE         ../../periph/aic/aic.inc

;-----------------
; PIO Controllers
;-----------------
        INCLUDE     periph/Pio/pio.inc

NB_PIO          EQU     31      ;- Number of PIO Lines

PIOTCLK0        EQU     0
PIOTIOA0        EQU     1
PIOTIOB0        EQU     2

PIOTCLK1        EQU     3
PIOTIOA1        EQU     4
PIOTIOB1        EQU     5

PIOTCLK2        EQU     6
PIOTIOA2        EQU     7
PIOTIOB2        EQU     8
 
PIOIRQ0         EQU     9
PIOIRQ1         EQU     10
PIOIRQ2         EQU     11
PIOFIQ          EQU     12

PIOSCK0         EQU     13
PIOTXD0         EQU     14
PIORXD0         EQU     15

PIOSCK1         EQU     20
PIOTXD1         EQU     21
PIORXD1         EQU     22

PIOMCK0         EQU     25
PIONCS2         EQU     26
PIONCS3         EQU     27
PIOCS7          EQU     28
PIOCS6          EQU     29
PIOCS5          EQU     30
PIOCS4          EQU     31

;---------
;- USARTs 
;---------
        INCLUDE     periph/usart/usart.inc

                END
